(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    256388,       7321]
NotebookOptionsPosition[    252465,       7184]
NotebookOutlinePosition[    253586,       7222]
CellTagsIndexPosition[    253327,       7213]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Load the package", "Section",
 CellChangeTimes->{{3.506347066803811*^9, 3.506347070894975*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "TRQS`"}]], "Input",
 CellChangeTimes->{{3.506268557364662*^9, 3.506268592296063*^9}, {
  3.506611307119945*^9, 3.506611315345665*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package TRQS version \"\>", 
   "\[InvisibleSpace]", "\<\"0.2.0\"\>", 
   "\[InvisibleSpace]", "\<\" (last modification: \"\>", 
   "\[InvisibleSpace]", "\<\"07/05/2012\"\>", 
   "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "Package TRQS version ", "0.2.0", " (last modification: ", "07/05/2012", 
   ")."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.507384108516549*^9, 3.507384115244271*^9}, 
   3.507386171844565*^9, {3.520958305679997*^9, 3.520958328595828*^9}, {
   3.520958379380396*^9, 3.520958383048226*^9}, {3.520958465356634*^9, 
   3.520958475525576*^9}, 3.54537800319235*^9, 3.545379626194599*^9, 
   3.54540198057167*^9}],

Cell[BoxData["\<\"\\!\\(\\*\\nStyleBox[\\\"INFO\\\",\\nFontWeight->\\\"Bold\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\":\\\",\\nFontWeight->\\\"Bold\\\"]\\)\\!\\(\\*\
\\nStyleBox[\\\" \\\",\\nFontWeight->\\\"Bold\\\"]\\)Using QRNG \
(https://qrng.physik.hu-berlin.de/) as a source of randomness.\"\>"], "Print",\

 CellChangeTimes->{{3.507384108516549*^9, 3.507384115244271*^9}, 
   3.507386171844565*^9, {3.520958305679997*^9, 3.520958328595828*^9}, {
   3.520958379380396*^9, 3.520958383048226*^9}, {3.520958465356634*^9, 
   3.520958475525576*^9}, 3.54537800319235*^9, 3.545379626194599*^9, 
   3.545401980576224*^9}],

Cell[BoxData["\<\"\\!\\(\\*\\nStyleBox[\\\"Note\\\",\\nFontWeight->\\\"Bold\\\
\"]\\)\\!\\(\\*\\nStyleBox[\\\":\\\",\\nFontWeight->\\\"Bold\\\"]\\) You have \
to use \\!\\(\\*\\nStyleBox[\\\"QRNGSetCredentials\\\",\\nFontWeight->\\\"\
Bold\\\"]\\) function to provide login information required to use this \
backend.\"\>"], "Print",
 CellChangeTimes->{{3.507384108516549*^9, 3.507384115244271*^9}, 
   3.507386171844565*^9, {3.520958305679997*^9, 3.520958328595828*^9}, {
   3.520958379380396*^9, 3.520958383048226*^9}, {3.520958465356634*^9, 
   3.520958475525576*^9}, 3.54537800319235*^9, 3.545379626194599*^9, 
   3.545401980578429*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setup used backend (QRNG)", "Section",
 CellChangeTimes->{{3.506347066803811*^9, 3.506347070894975*^9}, {
  3.54537802246926*^9, 3.545378038715907*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"?", "QRNGSetCredentials"}],
  FontWeight->"Bold"]], "Input",
 CellChangeTimes->{{3.545377813766058*^9, 3.545377816757354*^9}}],

Cell[BoxData[
 StyleBox["\<\"QRNGSetCredentials[user, pass] sets the username and the \
password used for connecting with the QRNG service \
(https://qrng.physik.hu-berlin.de/). This function must be used prior to \
using any functionality of the QRNG backend.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.545401984077039*^9},
 CellTags->"Info3545409183-1237171"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QRNGSetCredentials", "[", 
   RowBox[{"\"\<???????\>\"", ",", "\"\<???????\>\""}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "provide", " ", "the", " ", "login", " ", "information", " ", "for", " ", 
    "the", " ", "QRNG", " ", "service"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.5453781918326197`*^9, 3.5453782122734756`*^9}, {
  3.5453796339647837`*^9, 3.545379638618822*^9}, {3.545379724125661*^9, 
  3.545379731104787*^9}}],

Cell[BoxData["\<\"User name and password for using QRNG service set!\"\>"], \
"Print",
 CellChangeTimes->{3.545378046818625*^9, 3.5453796395025806`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check the connection", "Section",
 CellChangeTimes->{{3.5453796449147453`*^9, 3.545379651822034*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QRNGTestConnection", "[", "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"you", " ", "should", " ", "get", " ", "QRNG_SUCCESS"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.545379655072105*^9, 3.5453796618480377`*^9}, {
  3.545402009320514*^9, 3.545402023730455*^9}}],

Cell[BoxData["\<\"QRNG_SUCCESS\"\>"], "Output",
 CellChangeTimes->{3.545379663041507*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integer numbers", "Section",
 CellChangeTimes->{{3.506347058147935*^9, 3.5063470755042*^9}, {
  3.520958263984933*^9, 3.520958265212861*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "TrueRandomInteger"}]], "Input",
 CellChangeTimes->{{3.506345824551893*^9, 3.506345836419323*^9}, {
   3.506346011284359*^9, 3.506346040418538*^9}, 3.506346196873318*^9, {
   3.506346423853765*^9, 3.506346429035635*^9}, {3.506346507132716*^9, 
   3.506346508035354*^9}, 3.507384312534155*^9}],

Cell[BoxData[
 StyleBox["\<\"TrueRandomInteger[{i_min,i_max}] returns a random integer in \
the range [i_min,i_max].\\nTrueRandomInteger[{i_min, i_max}, dim] returns a \
list of random integers in the range [i_min, i_max] with dim \
elements.\\nTrueRandomInteger[i] returns a random integer in the range [0,i].\
\\nTrueRandomInteger[] returns 0 or 1.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.545379666890134*^9},
 CellTags->"Info3545386866-1127675"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TrueRandomInteger", "[", "]"}], ",", 
   RowBox[{"TrueRandomInteger", "[", "10", "]"}], ",", 
   RowBox[{"TrueRandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"10", ",", "20"}], "}"}], "]"}], ",", " ", 
   RowBox[{"TrueRandomInteger", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"10", ",", "20"}], "}"}], ",", "10"}], "]"}]}], "}"}]], "Input",\

 CellChangeTimes->{{3.506346523209384*^9, 3.506346545697158*^9}, {
  3.506346730232227*^9, 3.506346743023151*^9}, {3.506346836393783*^9, 
  3.506346849270452*^9}, {3.5453780581473293`*^9, 3.545378059875164*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "9", ",", "14", ",", 
   RowBox[{"{", 
    RowBox[{
    "11", ",", "18", ",", "16", ",", "20", ",", "10", ",", "12", ",", "19", 
     ",", "13", ",", "18", ",", "13"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.506346527164237*^9, 3.506346546286043*^9}, {
   3.506346726861028*^9, 3.506346745645706*^9}, {3.506346827204008*^9, 
   3.506346850367293*^9}, 3.506346988789919*^9, 3.50634704325*^9, 
   3.506347181045921*^9, 3.506347280089189*^9, {3.507386180212303*^9, 
   3.507386183773154*^9}, {3.545378052654652*^9, 3.5453780610147142`*^9}, 
   3.545379670119467*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Real numbers", "Section",
 CellChangeTimes->{{3.506347058147935*^9, 3.5063470755042*^9}, {
   3.506347135022176*^9, 3.506347135456531*^9}, 3.520958268005917*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "TrueRandomReal"}]], "Input",
 CellChangeTimes->{{3.506346820699346*^9, 3.506346822668754*^9}, 
   3.507384318675064*^9}],

Cell[BoxData[
 StyleBox["\<\"TrueRandomReal[{x_min,x_max}] returns a random double in the \
range [x_min,x_max].\\nTrueRandomReal[{x_min,x_max}, dim] returns a list of \
random double in the range [x_min,x_max] with dim \
elements.\\nTrueRandomReal[i] returns a random double in the range \
[0,x].\\nTrueRandomReal[] returns a random double in the range [0,1].\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.545379671719899*^9},
 CellTags->"Info3545386871-1127675"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TrueRandomReal", "[", "]"}], ",", 
   RowBox[{"TrueRandomReal", "[", "10", "]"}], ",", 
   RowBox[{"TrueRandomReal", "[", 
    RowBox[{"{", 
     RowBox[{"10", ",", "20"}], "}"}], "]"}], ",", 
   RowBox[{"TrueRandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"10", ",", "20"}], "}"}], ",", "10"}], "]"}]}], "}"}]], "Input",\

 CellChangeTimes->{{3.506346861014871*^9, 3.506346865506143*^9}, {
  3.545378067650136*^9, 3.545378069400909*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.5219686505926766`", ",", "0.28192351088190604`", ",", 
   "12.857090760871355`", ",", 
   RowBox[{"{", 
    RowBox[{
    "10.735224125674714`", ",", "17.208885450084722`", ",", 
     "12.18480173465542`", ",", "12.172960580796321`", ",", 
     "13.454870570158683`", ",", "13.394457756006426`", ",", 
     "17.906690044575768`", ",", "16.51156000891021`", ",", 
     "17.84878351968202`", ",", "14.084597267169347`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.50634686619123*^9, {3.506346962585041*^9, 3.506346989607223*^9}, 
   3.506347044011045*^9, {3.506347185054294*^9, 3.506347204358478*^9}, 
   3.506347283183944*^9, 3.507386190985959*^9, 3.5453780734795237`*^9, 
   3.5453796737852497`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normal distribution", "Section",
 CellChangeTimes->{{3.506348243925226*^9, 3.506348248859058*^9}, {
   3.506356694589777*^9, 3.506356695022201*^9}, 3.520958271371873*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "TrueRandomRealNormal"}]], "Input",
 CellChangeTimes->{{3.506348287782496*^9, 3.506348291002127*^9}, 
   3.507384326869874*^9}],

Cell[BoxData[
 StyleBox["\<\"TrueRandomRealNormal[m,s,dims] provides a sample of random \
numbers distributed according to the normal distribution N[m,s] in an array \
of dimensions given by dims.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.545379676912591*^9},
 CellTags->"Info3545386876-1127675"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"Flatten", "[", 
   RowBox[{"TrueRandomRealNormal", "[", 
    RowBox[{"0", ",", "1", ",", 
     RowBox[{"{", "10000", "}"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.50634720899722*^9, 3.506347223110237*^9}, {
  3.506347407772925*^9, 3.506347413205136*^9}, {3.506347515791752*^9, 
  3.506347553727021*^9}, {3.506348023464592*^9, 3.506348025433294*^9}, {
  3.506348269380923*^9, 3.506348283944947*^9}, {3.506348322716313*^9, 
  3.506348334926571*^9}, {3.506353945883461*^9, 3.506353980037371*^9}, {
  3.506354045034703*^9, 3.506354075512104*^9}, {3.506356680603117*^9, 
  3.506356684991688*^9}, {3.545378085082161*^9, 3.545378100098509*^9}}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
   EdgeForm[Opacity[0.7]], {}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.7]], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-4.2, 0.}, {-4., 1.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{18.5, 27.243331751305163`}, {94.73881447565904, 
         95.97256176651072}}],
       StatusArea[#, 1.]& ,
       TagBoxNote->"1."],
      StyleBox["1.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1., {
        GrayLevel[0]}], "Tooltip"]& ], {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-3.8, 0.}, {-3.6, 2.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{33.98666350261033, 42.72999525391549}, {
         94.50506718480736, 95.97256176651072}}],
       StatusArea[#, 2.]& ,
       TagBoxNote->"2."],
      StyleBox["2.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[2., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-3.6, 0.}, {-3.4, 3.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{41.72999525391549, 50.47332700522068}, {
         94.27131989395569, 95.97256176651072}}],
       StatusArea[#, 3.]& ,
       TagBoxNote->"3."],
      StyleBox["3.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[3., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-3.4, 0.}, {-3.2, 4.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{49.47332700522068, 58.216658756525845`}, {
         94.03757260310401, 95.97256176651072}}],
       StatusArea[#, 4.]& ,
       TagBoxNote->"4."],
      StyleBox["4.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[4., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-3.2, 0.}, {-3., 7.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{57.216658756525845`, 65.95999050783101}, {
         93.33633073054897, 95.97256176651072}}],
       StatusArea[#, 7.]& ,
       TagBoxNote->"7."],
      StyleBox["7.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[7., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-3., 0.}, {-2.8, 13.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{64.95999050783101, 73.70332225913619}, {
         91.9338469854389, 95.97256176651072}}],
       StatusArea[#, 13.]& ,
       TagBoxNote->"13."],
      StyleBox["13.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[13., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-2.8, 0.}, {-2.6, 25.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{72.70332225913619, 81.44665401044135}, {
         89.12887949521875, 95.97256176651072}}],
       StatusArea[#, 25.]& ,
       TagBoxNote->"25."],
      StyleBox["25.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[25., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-2.6, 0.}, {-2.4, 43.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{80.44665401044135, 89.18998576174653}, {
         84.92142825988854, 95.97256176651072}}],
       StatusArea[#, 43.]& ,
       TagBoxNote->"43."],
      StyleBox["43.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[43., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-2.4, 0.}, {-2.2, 55.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{88.18998576174653, 96.93331751305169}, {
         82.11646076966841, 95.97256176651072}}],
       StatusArea[#, 55.]& ,
       TagBoxNote->"55."],
      StyleBox["55.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[55., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-2.2, 0.}, {-2., 102.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{95.93331751305169, 104.67664926435687`}, {
         71.1303380996395, 95.97256176651072}}],
       StatusArea[#, 102.]& ,
       TagBoxNote->"102."],
      StyleBox["102.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[102., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-2., 0.}, {-1.8, 141.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{103.67664926435687`, 112.41998101566203`}, {
         62.01419375642404, 95.97256176651072}}],
       StatusArea[#, 141.]& ,
       TagBoxNote->"141."],
      StyleBox["141.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[141., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-1.8, 0.}, {-1.6, 222.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{111.41998101566203`, 120.16331276696721`}, {
         43.08066319743808, 95.97256176651072}}],
       StatusArea[#, 222.]& ,
       TagBoxNote->"222."],
      StyleBox["222.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[222., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-1.6, 0.}, {-1.4, 257.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{119.16331276696721`, 127.90664451827237`}, {
         34.89950801762932, 95.97256176651072}}],
       StatusArea[#, 257.]& ,
       TagBoxNote->"257."],
      StyleBox["257.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[257., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-1.4, 0.}, {-1.2, 338.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{126.90664451827237`, 135.64997626957756`}, {
         15.965977458643366`, 95.97256176651072}}],
       StatusArea[#, 338.]& ,
       TagBoxNote->"338."],
      StyleBox["338.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[338., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-1.2, 0.}, {-1., 455.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{134.64997626957756`, 
         143.39330802088273`}, {-11.382455571003035`, 95.97256176651072}}],
       StatusArea[#, 455.]& ,
       TagBoxNote->"455."],
      StyleBox["455.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[455., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-1., 0.}, {-0.8, 554.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{142.39330802088273`, 
         151.1366397721879}, {-34.52343736531921, 95.97256176651072}}],
       StatusArea[#, 554.]& ,
       TagBoxNote->"554."],
      StyleBox["554.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[554., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-0.8, 0.}, {-0.6, 627.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{150.1366397721879, 
         158.87997152349305`}, {-51.58698959749174, 95.97256176651072}}],
       StatusArea[#, 627.]& ,
       TagBoxNote->"627."],
      StyleBox["627.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[627., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-0.6, 0.}, {-0.4, 703.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{157.87997152349305`, 
         166.62330327479822`}, {-69.35178370221934, 95.97256176651072}}],
       StatusArea[#, 703.]& ,
       TagBoxNote->"703."],
      StyleBox["703.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[703., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-0.4, 0.}, {-0.2, 756.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{165.62330327479822`, 
         174.3666350261034}, {-81.74039011735829, 95.97256176651072}}],
       StatusArea[#, 756.]& ,
       TagBoxNote->"756."],
      StyleBox["756.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[756., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-0.2, 0.}, {0., 793.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{173.3666350261034, 
         182.10996677740857`}, {-90.38903987887039, 95.97256176651072}}],
       StatusArea[#, 793.]& ,
       TagBoxNote->"793."],
      StyleBox["793.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[793., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{0., 0.}, {0.2, 807.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{181.10996677740857`, 
         189.85329852871374`}, {-93.6615019507939, 95.97256176651072}}],
       StatusArea[#, 807.]& ,
       TagBoxNote->"807."],
      StyleBox["807.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[807., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{0.2, 0.}, {0.4, 744.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{188.85329852871374`, 
         197.59663028001893`}, {-78.93542262713814, 95.97256176651072}}],
       StatusArea[#, 744.]& ,
       TagBoxNote->"744."],
      StyleBox["744.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[744., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{0.4, 0.}, {0.6, 640.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{196.59663028001893`, 
         205.3399620313241}, {-54.62570437856357, 95.97256176651072}}],
       StatusArea[#, 640.]& ,
       TagBoxNote->"640."],
      StyleBox["640.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[640., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{0.6, 0.}, {0.8, 620.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{204.3399620313241, 
         213.08329378262926`}, {-49.950758561529994`, 95.97256176651072}}],
       StatusArea[#, 620.]& ,
       TagBoxNote->"620."],
      StyleBox["620.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[620., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{0.8, 0.}, {1., 539.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{212.08329378262926`, 
         220.82662553393442`}, {-31.01722800254403, 95.97256176651072}}],
       StatusArea[#, 539.]& ,
       TagBoxNote->"539."],
      StyleBox["539.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[539., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{1., 0.}, {1.2, 431.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{219.82662553393442`, 
         228.56995728523958`}, {-5.772520590562749, 95.97256176651072}}],
       StatusArea[#, 431.]& ,
       TagBoxNote->"431."],
      StyleBox["431.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[431., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{1.2, 0.}, {1.4, 325.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{227.56995728523958`, 236.31328903654477`}, {
         19.004692239715183`, 95.97256176651072}}],
       StatusArea[#, 325.]& ,
       TagBoxNote->"325."],
      StyleBox["325.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[325., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{1.4, 0.}, {1.6, 260.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{235.31328903654477`, 244.05662078784994`}, {
         34.19826614507429, 95.97256176651072}}],
       StatusArea[#, 260.]& ,
       TagBoxNote->"260."],
      StyleBox["260.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[260., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{1.6, 0.}, {1.8, 170.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{243.05662078784994`, 251.79995253915513`}, {
         55.23552232172536, 95.97256176651072}}],
       StatusArea[#, 170.]& ,
       TagBoxNote->"170."],
      StyleBox["170.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[170., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{1.8, 0.}, {2., 140.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{250.79995253915513`, 259.5432842904603}, {
         62.247941047275724`, 95.97256176651072}}],
       StatusArea[#, 140.]& ,
       TagBoxNote->"140."],
      StyleBox["140.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[140., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{2., 0.}, {2.2, 80.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{258.5432842904603, 267.28661604176546`}, {
         76.27277849837644, 95.97256176651072}}],
       StatusArea[#, 80.]& ,
       TagBoxNote->"80."],
      StyleBox["80.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[80., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{2.2, 0.}, {2.4, 48.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{266.28661604176546`, 275.0299477930706}, {
         83.75269180563015, 95.97256176651072}}],
       StatusArea[#, 48.]& ,
       TagBoxNote->"48."],
      StyleBox["48.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[48., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{2.4, 0.}, {2.6, 39.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{274.0299477930706, 282.7732795443758}, {
         85.85641742329526, 95.97256176651072}}],
       StatusArea[#, 39.]& ,
       TagBoxNote->"39."],
      StyleBox["39.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[39., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{2.6, 0.}, {2.8, 26.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{281.7732795443758, 290.51661129568095`}, {
         88.89513220436707, 95.97256176651072}}],
       StatusArea[#, 26.]& ,
       TagBoxNote->"26."],
      StyleBox["26.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[26., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{2.8, 0.}, {3., 15.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{289.51661129568095`, 298.2599430469861}, {
         91.46635240373554, 95.97256176651072}}],
       StatusArea[#, 15.]& ,
       TagBoxNote->"15."],
      StyleBox["15.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[15., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{3., 0.}, {3.2, 8.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{297.2599430469861, 306.0032747982913}, {
         93.1025834396973, 95.97256176651072}}],
       StatusArea[#, 8.]& ,
       TagBoxNote->"8."],
      StyleBox["8.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[8., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{3.2, 0.}, {3.4, 4.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{305.0032747982913, 313.74660654959644`}, {
         94.03757260310401, 95.97256176651072}}],
       StatusArea[#, 4.]& ,
       TagBoxNote->"4."],
      StyleBox["4.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[4., {
        GrayLevel[0]}], "Tooltip"]& ], {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{3.6, 0.}, {3.8, 2.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{320.48993830090166`, 329.2332700522068}, {
         94.50506718480736, 95.97256176651072}}],
       StatusArea[#, 2.]& ,
       TagBoxNote->"2."],
      StyleBox["2.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[2., {
        GrayLevel[0]}], "Tooltip"]& ], {}, {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{4.2, 0.}, {4.4, 1.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{343.71993355481715`, 352.46326530612237`}, {
         94.73881447565904, 95.97256176651072}}],
       StatusArea[#, 1.]& ,
       TagBoxNote->"1."],
      StyleBox["1.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1., {
        GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->{-4.2, 0},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  PlotRange->{{-4.2, 4.4}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.1]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.50635415999236*^9, {3.545378089398031*^9, 3.5453781021745663`*^9}, 
   3.545379679340432*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ginibre matrix", "Section",
 CellChangeTimes->{{3.506356822382372*^9, 3.506356835920143*^9}, 
   3.520958275044531*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "TrueGinibreMatrix"}]], "Input",
 CellChangeTimes->{{3.507384336338703*^9, 3.507384338738904*^9}}],

Cell[BoxData[
 StyleBox["\<\"TrueGinibreMatrix[m,n] returns (m x n)-dimensional complex \
matrix with entries having real and complex parts distributed according to \
the normal distribution N[0,1].\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.545379685707758*^9},
 CellTags->"Info3545386885-1127675"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrueGinibreMatrix", "[", 
  RowBox[{"10", ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.506356837429805*^9, 3.506356862018918*^9}, {
  3.506356909863082*^9, 3.506356912371302*^9}, {3.506357327294393*^9, 
  3.506357368681925*^9}, {3.507384345248601*^9, 3.507384354917237*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.10833859638176566`"}], "-", 
      RowBox[{"0.6294397315616126`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.1655751937936196`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.6331791693766655`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.7525894602049302`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.9118256613730474`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2.0740713367057526`"}], "+", 
      RowBox[{"0.9364906363718999`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.8181690167862313`"}], "+", 
      RowBox[{"0.5954297493301854`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.8819256116764876`"}], "+", 
      RowBox[{"0.05973998399812146`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.4824260474634952`"}], "+", 
      RowBox[{"1.8471297194594356`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.9510625889394739`"}], "-", 
      RowBox[{"2.5626815792332067`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.6138289768371965`"}], "-", 
      RowBox[{"0.8651810399186313`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.269915598543672`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.0690900599172497`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.3074120014507649`"}], "-", 
      RowBox[{"0.9114231530007914`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.915561369292076`"}], "+", 
      RowBox[{"1.0626780951826698`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.37514953746221535`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.1278269718284911`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.5113410798740486`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.5476871409234559`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.16739057456477335`"}], "+", 
      RowBox[{"0.8093032107465817`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.40458481325223666`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.5475074108773316`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2.338997578541355`"}], "+", 
      RowBox[{"0.6574019907008041`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.7788379541018581`"}], "-", 
      RowBox[{"0.8348613790719007`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.3194808681992411`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.8029706974297088`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.13964861723799765`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.7462533728067648`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.1126766800668029`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.21334626219890232`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.14999754142041347`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.5491786970987348`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.4548171606907585`"}], "-", 
      RowBox[{"0.4897997247003094`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.012938404569936926`"}], "+", 
      RowBox[{"0.4349951717957915`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.897747394965192`"}], "-", 
      RowBox[{"0.3056654833858716`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.160611368227198`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.05393925812055596`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.18676114178226716`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.5266693012051553`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.7388520276748906`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.07630959723096489`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.2226514961106594`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.7275119349305886`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.6352328927985829`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.4742256423614645`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.7990259386169245`"}], "+", 
      RowBox[{"0.653205515678578`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.9109853328266889`"}], "-", 
      RowBox[{"0.5970740810254339`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.6349469087833242`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.25953407943536044`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.7579978023178602`"}], "+", 
      RowBox[{"1.6964246346271488`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.42843875072186177`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.8813278074330663`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"2.096529875921439`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.6428643426268683`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.27722482000951076`"}], "-", 
      RowBox[{"1.446224774795244`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.04698433669656577`"}], "-", 
      RowBox[{"0.29295067160483673`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.028190205188391`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.20062435057125774`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.374573178476091`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.9587663250392658`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.07424148400891765`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.960979730713633`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.9182605963679258`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.2474955590535959`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.22637513597791611`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.25685039898342243`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.7373076740362157`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.7125410841906035`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.4194596424053038`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.5772235158870941`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.3945171502854195`"}], "-", 
      RowBox[{"0.9077121065795621`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2.392188972616601`"}], "+", 
      RowBox[{"0.40028725993451764`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.8633307635273683`"}], "+", 
      RowBox[{"1.3223167799705045`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.3705886846134974`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.8398333953193212`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.8478106353269823`"}], "-", 
      RowBox[{"2.070433047619187`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.9159423650725981`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.4140049429229096`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.5781537808449861`"}], "-", 
      RowBox[{"0.3209204111711871`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.3722687586757837`"}], "-", 
      RowBox[{"0.07681958037864109`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.09839481017839079`"}], "+", 
      RowBox[{"2.67489962098808`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.1769285826210172`"}], "-", 
      RowBox[{"0.49523768706249577`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.4143947694968155`"}], "-", 
      RowBox[{"0.4328958405547667`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.9686859522110103`"}], "+", 
      RowBox[{"1.9984438281515577`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.033339639341983245`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.3232158059531623`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.028017638100283`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.3867159660825751`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.2403831109973347`"}], "-", 
      RowBox[{"0.14908003271558815`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.3592607085216077`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.9179585566667563`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.7216065557600633`"}], "-", 
      RowBox[{"0.8994281914327923`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.5740368112480936`"}], "-", 
      RowBox[{"1.2735391846569093`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.7200167832181384`"}], "+", 
      RowBox[{"0.5261069994975869`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.14510567980589129`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.010479593015176961`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.6131173485168142`"}], "+", 
      RowBox[{"0.2566867255940701`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.0003240994773124`"}], "-", 
      RowBox[{"0.4914135050002823`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.8210686164832258`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.0152998983953936`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.3922736707791338`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.556593264812235`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.2131353523687495`"}], "+", 
      RowBox[{"2.960674362641756`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.8580901373381002`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.6685981351562985`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.8567251924980814`"}], "+", 
      RowBox[{"1.0586443320454673`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.5861566341690092`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.0310844991540595`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.4833468340599225`", "\[VeryThinSpace]", "-", 
      RowBox[{"2.5337096801722088`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.10800783932282651`"}], "-", 
      RowBox[{"0.401638032047701`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.794430549759447`"}], "-", 
      RowBox[{"1.5329382684129274`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.7296893504914959`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.7043139069728838`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.4857354421113276`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.3458110722972418`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.11145253129383714`"}], "+", 
      RowBox[{"0.5246900231146082`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.9240165053886201`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.6456215076821924`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.1852486867198769`"}], "+", 
      RowBox[{"0.18713005679724845`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.5342218967959311`"}], "-", 
      RowBox[{"1.0962741809807957`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2.626157184405782`"}], "+", 
      RowBox[{"1.7675580209099866`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.0029080951702798335`"}], "-", 
      RowBox[{"1.189389875536763`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.0130203276996903`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.10983105684234383`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.7040161941331522`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.16291866039566794`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.03432256106908583`"}], "+", 
      RowBox[{"0.9843985642885217`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.5224124903510666`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.3433265071805744`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.3639606054004352`"}], "+", 
      RowBox[{"0.7235116995809397`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.6786388243305386`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.4300343714277195`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.669162458951285`"}], "-", 
      RowBox[{"1.73476443998631`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.637415467028963`"}], "+", 
      RowBox[{"1.1487637553624055`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.27269013523155217`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.6069858805250767`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.783655844553081`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.145928305897746`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "0.5218064199774364`"}], "+", 
      RowBox[{"0.3912383612746973`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.8605832622667278`"}], "-", 
      RowBox[{"0.8301677141252045`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"2.1569168051671244`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.8482205414378118`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.8199308042932133`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.5721003525696233`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"1.1067648587251333`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.1625201189817211`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.6813610527578396`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.30584173915760504`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.507384355393715*^9, 3.507386200920452*^9, 
  3.545378107838065*^9, 3.545379686450769*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random states - HS measure", "Section",
 CellChangeTimes->{{3.506357313241281*^9, 3.506357319119641*^9}, {
   3.507384018680895*^9, 3.507384022556726*^9}, 3.520958278229198*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"statesHS", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"TrueRandomStateHS", "[", "4", "]"}], ",", 
     RowBox[{"{", "2000", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.506356955714329*^9, 3.506356963435738*^9}, {
   3.506357029088053*^9, 3.506357042149422*^9}, {3.506357086546097*^9, 
   3.506357086810156*^9}, 3.506357504993437*^9, {3.506611404603314*^9, 
   3.506611405108216*^9}, {3.506611481524189*^9, 3.506611481700257*^9}, {
   3.506612362083802*^9, 3.506612362178205*^9}, {3.50661240589702*^9, 
   3.50661241166613*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sortedEvalsHS", "=", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Sort", "[", "#", "]"}], "&"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Chop", "[", 
          RowBox[{"Eigenvalues", "[", "#", "]"}], "]"}], "&"}], ",", 
        "statesHS"}], "]"}]}], "]"}], "\[Transpose]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.506357448406956*^9, 3.506357453371821*^9}, {
  3.506358646570169*^9, 3.506358671602652*^9}, {3.506609083334995*^9, 
  3.506609084492685*^9}, {3.506612364750218*^9, 3.506612367185656*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"masterplotHS", "=", 
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sortedEvalsHS", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"sortedEvalsHS", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"sortedEvalsHS", "[", 
        RowBox[{"[", "3", "]"}], "]"}], ",", 
       RowBox[{"sortedEvalsHS", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", "0.005", "}"}], ",", "\"\<ProbabilityDensity\>\"", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "61"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ChartBaseStyle", "\[Rule]", 
      RowBox[{"EdgeForm", "[", "None", "]"}]}], ",", 
     RowBox[{"ChartStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Gray", ",", 
        RowBox[{"Darker", "[", "Gray", "]"}], ",", "LightGray", ",", 
        RowBox[{"Darker", "[", "LightGray", "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[Lambda]\>\"", ",", "\"\<P(\[Lambda])\>\""}], "}"}]}], 
     ",", 
     RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", " ", "15"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.506358054231736*^9, 3.506358150934111*^9}, {
   3.506358211584388*^9, 3.506358212411872*^9}, {3.506609070634612*^9, 
   3.506609071453995*^9}, {3.50660911577775*^9, 3.506609143041301*^9}, {
   3.506611418917231*^9, 3.506611425486547*^9}, {3.506611466049271*^9, 
   3.50661147002345*^9}, {3.506612375469112*^9, 3.506612380085457*^9}, 
   3.506612425089051*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{
    RowBox[{"ToString", "[", 
     RowBox[{"NotebookDirectory", "[", "]"}], "]"}], "<>", "\"\</plots\>\""}],
    "]"}], ";"}]], "Input",
 CellChangeTimes->{3.506358245795662*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<lambda-prob-hs-trqs.pdf\>\"", ",", "masterplotHS"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Run", "[", 
   "\"\< pdf2ps  -dLanguageLevel=3 lambda-prob-hs-trqs.pdf \
lambda-prob-hs-trqs.eps\>\"", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.506358188785643*^9, 3.506358204681434*^9}, 
   3.506358540566231*^9, {3.506612384941042*^9, 3.506612401349774*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random states - Bures measure", "Section",
 CellChangeTimes->{{3.506357313241281*^9, 3.506357319119641*^9}, {
   3.506611754111532*^9, 3.506611759073554*^9}, {3.50738402438571*^9, 
   3.507384027307377*^9}, 3.520958280506277*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"statesBures", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"TrueRandomStateBures", "[", "4", "]"}], ",", 
     RowBox[{"{", "1000", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.506356955714329*^9, 3.506356963435738*^9}, {
   3.506357029088053*^9, 3.506357042149422*^9}, {3.506357086546097*^9, 
   3.506357086810156*^9}, 3.506357504993437*^9, {3.506611404603314*^9, 
   3.506611405108216*^9}, {3.506611481524189*^9, 3.506611481700257*^9}, {
   3.506611763218933*^9, 3.506611767578857*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sortedEvalsBures", "=", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Sort", "[", "#", "]"}], "&"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Chop", "[", 
          RowBox[{"Eigenvalues", "[", "#", "]"}], "]"}], "&"}], ",", 
        "statesBures"}], "]"}]}], "]"}], "\[Transpose]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.506357448406956*^9, 3.506357453371821*^9}, {
  3.506358646570169*^9, 3.506358671602652*^9}, {3.506609083334995*^9, 
  3.506609084492685*^9}, {3.506611770494716*^9, 3.506611774755524*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"sortedEvalsBures", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"sortedEvalsBures", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"sortedEvalsBures", "[", 
     RowBox[{"[", "3", "]"}], "]"}], ",", 
    RowBox[{"sortedEvalsBures", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.506611779315157*^9, 3.506611785444733*^9}}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
   EdgeForm[Opacity[0.7]], {{}, 
    {RGBColor[0.24720000000000017`, 0.24, 0.6], Opacity[0.5], EdgeForm[
     Opacity[0.7]], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0., 0.}, {0.05, 997.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{23.499999999999993`, 
          40.89999999999999}, {-92.28383871771196, 94.53838056642304}}],
        StatusArea[#, 997.]& ,
        TagBoxNote->"997."],
       StyleBox["997.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[997., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.05, 0.}, {0.1, 3.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{39.89999999999999, 57.29999999999999}, {
          92.97923647630027, 94.53838056642304}}],
        StatusArea[#, 3.]& ,
        TagBoxNote->"3."],
       StyleBox["3.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3., {
         GrayLevel[0]}], 
       "Tooltip"]& ], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}}, {}, {}}, {{}, 
    {RGBColor[0.6, 0.24, 0.4428931686004542], Opacity[0.5], EdgeForm[Opacity[
     0.7]], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0., 0.}, {0.05, 525.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{23.499999999999993`, 
          40.89999999999999}, {-4.311835205062295, 94.53838056642304}}],
        StatusArea[#, 525.]& ,
        TagBoxNote->"525."],
       StyleBox["525.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[525., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.05, 0.}, {0.1, 351.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{39.89999999999999, 57.29999999999999}, {
          28.118522022058556`, 94.53838056642304}}],
        StatusArea[#, 351.]& ,
        TagBoxNote->"351."],
       StyleBox["351.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[351., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.1, 0.}, {0.15, 111.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{56.29999999999999, 73.69999999999999}, {
          72.85004923188043, 94.53838056642304}}],
        StatusArea[#, 111.]& ,
        TagBoxNote->"111."],
       StyleBox["111.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[111., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.15, 0.}, {0.2, 12.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{72.69999999999999, 90.1}, {91.30180420593194, 
          94.53838056642304}}],
        StatusArea[#, 12.]& ,
        TagBoxNote->"12."],
       StyleBox["12.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[12., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.2, 0.}, {0.25, 1.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{89.1, 106.49999999999997`}, {93.35199920304879, 
          94.53838056642304}}],
        StatusArea[#, 1.]& ,
        TagBoxNote->"1."],
       StyleBox["1.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1., {
         GrayLevel[0]}], 
       "Tooltip"]& ], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}}, {}, {}}, {{}, 
    {RGBColor[0.6, 0.5470136627990908, 0.24], Opacity[0.5], EdgeForm[Opacity[
     0.7]], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0., 0.}, {0.05, 3.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{23.499999999999993`, 40.89999999999999}, {
          92.97923647630027, 94.53838056642304}}],
        StatusArea[#, 3.]& ,
        TagBoxNote->"3."],
       StyleBox["3.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.05, 0.}, {0.1, 28.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{39.89999999999999, 57.29999999999999}, {
          88.31970239194382, 94.53838056642304}}],
        StatusArea[#, 28.]& ,
        TagBoxNote->"28."],
       StyleBox["28.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[28., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.1, 0.}, {0.15, 112.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{56.29999999999999, 73.69999999999999}, {
          72.66366786850617, 94.53838056642304}}],
        StatusArea[#, 112.]& ,
        TagBoxNote->"112."],
       StyleBox["112.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[112., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.15, 0.}, {0.2, 184.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{72.69999999999999, 90.1}, {59.24420970555961, 
          94.53838056642304}}],
        StatusArea[#, 184.]& ,
        TagBoxNote->"184."],
       StyleBox["184.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[184., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.2, 0.}, {0.25, 239.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{89.1, 106.49999999999997`}, {48.99323471997543, 
          94.53838056642304}}],
        StatusArea[#, 239.]& ,
        TagBoxNote->"239."],
       StyleBox["239.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[239., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.25, 0.}, {0.3, 202.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{105.49999999999997`, 122.89999999999998`}, {
          55.88934516482297, 94.53838056642304}}],
        StatusArea[#, 202.]& ,
        TagBoxNote->"202."],
       StyleBox["202.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[202., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.3, 0.}, {0.35, 135.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{121.89999999999998`, 139.29999999999995`}, {
          68.37689651089823, 94.53838056642304}}],
        StatusArea[#, 135.]& ,
        TagBoxNote->"135."],
       StyleBox["135.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[135., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.35, 0.}, {0.4, 72.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{138.29999999999995`, 155.7}, {80.11892240347649, 
          94.53838056642304}}],
        StatusArea[#, 72.]& ,
        TagBoxNote->"72."],
       StyleBox["72.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[72., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.4, 0.}, {0.45, 23.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{154.7, 172.09999999999997`}, {89.25160920881511, 
          94.53838056642304}}],
        StatusArea[#, 23.]& ,
        TagBoxNote->"23."],
       StyleBox["23.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[23., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.45, 0.}, {0.5, 2.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{171.09999999999997`, 188.49999999999997`}, {
          93.16561783967452, 94.53838056642304}}],
        StatusArea[#, 2.]& ,
        TagBoxNote->"2."],
       StyleBox["2.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2., {
         GrayLevel[0]}], 
       "Tooltip"]& ], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {}, {}}, {{}, 
    {RGBColor[0.24, 0.6, 0.33692049419863584`], Opacity[0.5], EdgeForm[
     Opacity[0.7]], {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.45, 0.}, {0.5, 11.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{171.09999999999997`, 188.49999999999997`}, {
          91.48818556930621, 94.53838056642304}}],
        StatusArea[#, 11.]& ,
        TagBoxNote->"11."],
       StyleBox["11.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[11., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.5, 0.}, {0.55, 54.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{187.49999999999997`, 204.89999999999998`}, {
          83.47378694421312, 94.53838056642304}}],
        StatusArea[#, 54.]& ,
        TagBoxNote->"54."],
       StyleBox["54.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[54., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.55, 0.}, {0.6, 99.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{203.89999999999998`, 221.29999999999995`}, {
          75.08662559237152, 94.53838056642304}}],
        StatusArea[#, 99.]& ,
        TagBoxNote->"99."],
       StyleBox["99.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[99., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.6, 0.}, {0.65, 146.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{220.29999999999995`, 237.69999999999996`}, {
          66.32670151378142, 94.53838056642304}}],
        StatusArea[#, 146.]& ,
        TagBoxNote->"146."],
       StyleBox["146.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[146., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.65, 0.}, {0.7, 184.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{236.69999999999996`, 254.09999999999994`}, {
          59.24420970555961, 94.53838056642304}}],
        StatusArea[#, 184.]& ,
        TagBoxNote->"184."],
       StyleBox["184.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[184., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.7, 0.}, {0.75, 188.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{253.09999999999994`, 270.49999999999994`}, {
          58.49868425206258, 94.53838056642304}}],
        StatusArea[#, 188.]& ,
        TagBoxNote->"188."],
       StyleBox["188.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[188., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.75, 0.}, {0.8, 161.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{269.49999999999994`, 286.9}, {63.530981063167545`, 
          94.53838056642304}}],
        StatusArea[#, 161.]& ,
        TagBoxNote->"161."],
       StyleBox["161.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[161., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.8, 0.}, {0.85, 95.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{285.9, 303.29999999999995`}, {75.83215104586856, 
          94.53838056642304}}],
        StatusArea[#, 95.]& ,
        TagBoxNote->"95."],
       StyleBox["95.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[95., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.85, 0.}, {0.9, 50.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{302.29999999999995`, 319.69999999999993`}, {
          84.21931239771015, 94.53838056642304}}],
        StatusArea[#, 50.]& ,
        TagBoxNote->"50."],
       StyleBox["50.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[50., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.9, 0.}, {0.95, 10.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{318.69999999999993`, 336.0999999999999}, {
          91.67456693268046, 94.53838056642304}}],
        StatusArea[#, 10.]& ,
        TagBoxNote->"10."],
       StyleBox["10.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[10., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.95, 0.}, {1., 2.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{335.0999999999999, 352.49999999999994`}, {
          93.16561783967452, 94.53838056642304}}],
        StatusArea[#, 2.]& ,
        TagBoxNote->"2."],
       StyleBox["2.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2., {
         GrayLevel[0]}], "Tooltip"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->{0., 0},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  PlotRange->{{0, 1}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.1]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.506358026663165*^9, 3.506358626655122*^9, 
  3.506358676231659*^9, 3.506611412941515*^9, 3.506612317969519*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"masterplotBures", "=", 
  RowBox[{"Histogram", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sortedEvalsBures", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"sortedEvalsBures", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"sortedEvalsBures", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", 
      RowBox[{"sortedEvalsBures", "[", 
       RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", "0.005", "}"}], ",", "\"\<ProbabilityDensity\>\"", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "61"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"ChartBaseStyle", "\[Rule]", 
     RowBox[{"EdgeForm", "[", "None", "]"}]}], ",", 
    RowBox[{"ChartStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Gray", ",", 
       RowBox[{"Darker", "[", "Gray", "]"}], ",", "LightGray", ",", 
       RowBox[{"Darker", "[", "LightGray", "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\[Lambda]\>\"", ",", "\"\<P(\[Lambda])\>\""}], "}"}]}], 
    ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", " ", "15"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.506358054231736*^9, 3.506358150934111*^9}, {
  3.506358211584388*^9, 3.506358212411872*^9}, {3.506609070634612*^9, 
  3.506609071453995*^9}, {3.50660911577775*^9, 3.506609143041301*^9}, {
  3.506611418917231*^9, 3.506611425486547*^9}, {3.506611466049271*^9, 
  3.50661147002345*^9}, {3.506611787913073*^9, 3.506611799573698*^9}}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
   EdgeForm[None], {{}, 
    {GrayLevel[0.5], Opacity[0.5], EdgeForm[None], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0., 0.}, {0.005, 145.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{19.000000000000004`, 
          21.700000000000003`}, {-627.5741267163153, 165.7383539249431}}],
        StatusArea[#, 145.]& ,
        TagBoxNote->"145."],
       StyleBox["145.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[145., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.005, 0.}, {0.01, 26.400000000000002`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{21.700000000000003`, 24.400000000000006`}, {
          21.300771242672624`, 165.73835392494314`}}],
        StatusArea[#, 26.400000000000002`]& ,
        TagBoxNote->"26.400000000000002"],
       StyleBox["26.400000000000002`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[26.400000000000002`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.01, 0.}, {0.015, 12.800000000000002`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{24.400000000000006`, 27.1}, {95.70801080626653, 
          165.73835392494314`}}],
        StatusArea[#, 12.800000000000002`]& ,
        TagBoxNote->"12.800000000000002"],
       StyleBox["12.800000000000002`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[12.800000000000002`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.015, 0.}, {0.02, 7.199999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{27.1, 29.800000000000004`}, {126.34628592068756`, 
          165.73835392494314`}}],
        StatusArea[#, 7.199999999999998]& ,
        TagBoxNote->"7.199999999999998"],
       StyleBox["7.199999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[7.199999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.02, 0.}, {0.025, 3.4}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{29.800000000000004`, 32.5}, {147.13654403404468`, 
          165.73835392494314`}}],
        StatusArea[#, 3.4]& ,
        TagBoxNote->"3.4"],
       StyleBox["3.4`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.4, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.025, 0.}, {0.03, 1.600000000000001}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{32.5, 35.2}, {156.98456103510856`, 
          165.73835392494314`}}],
        StatusArea[#, 1.600000000000001]& ,
        TagBoxNote->"1.600000000000001"],
       StyleBox["1.600000000000001`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.600000000000001, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.03, 0.}, {0.035, 1.5999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{35.2, 37.900000000000006`}, {156.98456103510858`, 
          165.73835392494314`}}],
        StatusArea[#, 1.5999999999999988`]& ,
        TagBoxNote->"1.5999999999999988"],
       StyleBox["1.5999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.5999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.035, 0.}, {0.04, 0.8000000000000005}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{37.900000000000006`, 40.60000000000001}, {
          161.36145748002585`, 165.73835392494314`}}],
        StatusArea[#, 0.8000000000000005]& ,
        TagBoxNote->"0.8000000000000005"],
       StyleBox["0.8000000000000005`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.8000000000000005, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.04, 0.}, {0.045, 0.6000000000000003}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{40.60000000000001, 43.300000000000004`}, {
          162.45568159125517`, 165.73835392494314`}}],
        StatusArea[#, 0.6000000000000003]& ,
        TagBoxNote->"0.6000000000000003"],
       StyleBox["0.6000000000000003`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.6000000000000003, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.05, 0.}, {0.055, 0.40000000000000024`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{46., 48.7}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.40000000000000024`]& ,
        TagBoxNote->"0.40000000000000024"],
       StyleBox["0.40000000000000024`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.40000000000000024`, {
         GrayLevel[0]}], "Tooltip"]& ], {}, {}, {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.07, 0.}, {0.075, 0.20000000000000037`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{56.80000000000001, 59.5}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.20000000000000037`]& ,
        TagBoxNote->"0.20000000000000037"],
       StyleBox["0.20000000000000037`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.20000000000000037`, {
         GrayLevel[0]}], 
       "Tooltip"]& ], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {}, {}}, {{}, 
    {RGBColor[
     0.33333333333333337`, 0.33333333333333337`, 0.33333333333333337`], 
     Opacity[0.5], EdgeForm[None], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0., 0.}, {0.005, 2.4}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{19.000000000000004`, 21.700000000000003`}, {
          152.6076645901913, 165.73835392494314`}}],
        StatusArea[#, 2.4]& ,
        TagBoxNote->"2.4"],
       StyleBox["2.4`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.4, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.005, 0.}, {0.01, 8.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{21.700000000000003`, 24.400000000000006`}, {
          121.96938947577027`, 165.73835392494314`}}],
        StatusArea[#, 8.]& ,
        TagBoxNote->"8."],
       StyleBox["8.`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[8., {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.01, 0.}, {0.015, 8.8}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{24.400000000000006`, 27.1}, {117.59249303085298`, 
          165.73835392494314`}}],
        StatusArea[#, 8.8]& ,
        TagBoxNote->"8.8"],
       StyleBox["8.8`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[8.8, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.015, 0.}, {0.02, 13.2}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{27.1, 29.800000000000004`}, {93.5195625838079, 
          165.73835392494314`}}],
        StatusArea[#, 13.2]& ,
        TagBoxNote->"13.2"],
       StyleBox["13.2`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[13.2, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.02, 0.}, {0.025, 9.6}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{29.800000000000004`, 32.5}, {113.21559658593569`, 
          165.73835392494314`}}],
        StatusArea[#, 9.6]& ,
        TagBoxNote->"9.6"],
       StyleBox["9.6`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[9.6, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.025, 0.}, {0.03, 13.80000000000001}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{32.5, 35.2}, {90.23689025011987, 
          165.73835392494314`}}],
        StatusArea[#, 13.80000000000001]& ,
        TagBoxNote->"13.80000000000001"],
       StyleBox["13.80000000000001`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[13.80000000000001, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.03, 0.}, {0.035, 12.39999999999999}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{35.2, 37.900000000000006`}, {97.89645902872523, 
          165.73835392494314`}}],
        StatusArea[#, 12.39999999999999]& ,
        TagBoxNote->"12.39999999999999"],
       StyleBox["12.39999999999999`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[12.39999999999999, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.035, 0.}, {0.04, 13.80000000000001}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{37.900000000000006`, 40.60000000000001}, {
          90.23689025011987, 165.73835392494314`}}],
        StatusArea[#, 13.80000000000001]& ,
        TagBoxNote->"13.80000000000001"],
       StyleBox["13.80000000000001`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[13.80000000000001, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.04, 0.}, {0.045, 11.600000000000007`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{40.60000000000001, 43.300000000000004`}, {
          102.27335547364243`, 165.73835392494314`}}],
        StatusArea[#, 11.600000000000007`]& ,
        TagBoxNote->"11.600000000000007"],
       StyleBox["11.600000000000007`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[11.600000000000007`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.045, 0.}, {0.05, 11.399999999999991`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{43.300000000000004`, 46.}, {103.36757958487183`, 
          165.73835392494314`}}],
        StatusArea[#, 11.399999999999991`]& ,
        TagBoxNote->"11.399999999999991"],
       StyleBox["11.399999999999991`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[11.399999999999991`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.05, 0.}, {0.055, 11.000000000000007`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{46., 48.7}, {105.5560278073304, 
          165.73835392494314`}}],
        StatusArea[#, 11.000000000000007`]& ,
        TagBoxNote->"11.000000000000007"],
       StyleBox["11.000000000000007`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[11.000000000000007`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.055, 0.}, {0.06, 7.400000000000004}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{48.7, 51.400000000000006`}, {125.25206180945821`, 
          165.73835392494314`}}],
        StatusArea[#, 7.400000000000004]& ,
        TagBoxNote->"7.400000000000004"],
       StyleBox["7.400000000000004`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[7.400000000000004, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.06, 0.}, {0.065, 10.19999999999999}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{51.400000000000006`, 54.10000000000001}, {
          109.93292425224777`, 165.73835392494314`}}],
        StatusArea[#, 10.19999999999999]& ,
        TagBoxNote->"10.19999999999999"],
       StyleBox["10.19999999999999`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[10.19999999999999, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.065, 0.}, {0.07, 6.599999999999994}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{54.10000000000001, 56.80000000000001}, {
          129.62895825437556`, 165.73835392494314`}}],
        StatusArea[#, 6.599999999999994]& ,
        TagBoxNote->"6.599999999999994"],
       StyleBox["6.599999999999994`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[6.599999999999994, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.07, 0.}, {0.075, 7.400000000000014}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{56.80000000000001, 59.5}, {125.25206180945816`, 
          165.73835392494314`}}],
        StatusArea[#, 7.400000000000014]& ,
        TagBoxNote->"7.400000000000014"],
       StyleBox["7.400000000000014`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[7.400000000000014, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.075, 0.}, {0.08, 6.399999999999995}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{59.5, 62.2}, {130.72318236560486`, 
          165.73835392494314`}}],
        StatusArea[#, 6.399999999999995]& ,
        TagBoxNote->"6.399999999999995"],
       StyleBox["6.399999999999995`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[6.399999999999995, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.08, 0.}, {0.085, 5.799999999999995}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{62.2, 64.9}, {134.00585469929283`, 
          165.73835392494314`}}],
        StatusArea[#, 5.799999999999995]& ,
        TagBoxNote->"5.799999999999995"],
       StyleBox["5.799999999999995`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[5.799999999999995, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.085, 0.}, {0.09, 6.400000000000012}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{64.9, 67.60000000000001}, {130.72318236560477`, 
          165.73835392494314`}}],
        StatusArea[#, 6.400000000000012]& ,
        TagBoxNote->"6.400000000000012"],
       StyleBox["6.400000000000012`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[6.400000000000012, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.09, 0.}, {0.095, 4.199999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{67.60000000000001, 70.3}, {142.7596475891274, 
          165.73835392494314`}}],
        StatusArea[#, 4.199999999999997]& ,
        TagBoxNote->"4.199999999999997"],
       StyleBox["4.199999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.199999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.095, 0.}, {0.1, 4.799999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{70.3, 73.}, {139.47697525543944`, 
          165.73835392494314`}}],
        StatusArea[#, 4.799999999999996]& ,
        TagBoxNote->"4.799999999999996"],
       StyleBox["4.799999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.799999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.1, 0.}, {0.105, 3.0000000000000053`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{73., 75.7}, {149.3249922565033, 
          165.73835392494314`}}],
        StatusArea[#, 3.0000000000000053`]& ,
        TagBoxNote->"3.0000000000000053"],
       StyleBox["3.0000000000000053`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.0000000000000053`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.105, 0.}, {0.11, 4.199999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{75.7, 78.4}, {142.7596475891274, 
          165.73835392494314`}}],
        StatusArea[#, 4.199999999999997]& ,
        TagBoxNote->"4.199999999999997"],
       StyleBox["4.199999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.199999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.11, 0.}, {0.115, 1.9999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{78.4, 81.10000000000001}, {154.79611281264994`, 
          165.73835392494314`}}],
        StatusArea[#, 1.9999999999999984`]& ,
        TagBoxNote->"1.9999999999999984"],
       StyleBox["1.9999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.9999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.115, 0.}, {0.12, 2.800000000000005}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{81.10000000000001, 83.8}, {150.41921636773262`, 
          165.73835392494314`}}],
        StatusArea[#, 2.800000000000005]& ,
        TagBoxNote->"2.800000000000005"],
       StyleBox["2.800000000000005`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.800000000000005, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.12, 0.}, {0.125, 2.7999999999999976`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{83.8, 86.5}, {150.41921636773264`, 
          165.73835392494314`}}],
        StatusArea[#, 2.7999999999999976`]& ,
        TagBoxNote->"2.7999999999999976"],
       StyleBox["2.7999999999999976`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.7999999999999976`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.125, 0.}, {0.13, 1.7999999999999983`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{86.5, 89.2}, {155.89033692387926`, 
          165.73835392494314`}}],
        StatusArea[#, 1.7999999999999983`]& ,
        TagBoxNote->"1.7999999999999983"],
       StyleBox["1.7999999999999983`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.7999999999999983`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.13, 0.}, {0.135, 1.5999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{89.2, 91.9}, {156.98456103510858`, 
          165.73835392494314`}}],
        StatusArea[#, 1.5999999999999988`]& ,
        TagBoxNote->"1.5999999999999988"],
       StyleBox["1.5999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.5999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.135, 0.}, {0.14, 1.199999999999999}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{91.9, 94.60000000000001}, {159.1730092575672, 
          165.73835392494314`}}],
        StatusArea[#, 1.199999999999999]& ,
        TagBoxNote->"1.199999999999999"],
       StyleBox["1.199999999999999`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.199999999999999, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.14, 0.}, {0.145, 1.2000000000000057`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{94.60000000000001, 97.3}, {159.17300925756717`, 
          165.73835392494314`}}],
        StatusArea[#, 1.2000000000000057`]& ,
        TagBoxNote->"1.2000000000000057"],
       StyleBox["1.2000000000000057`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.2000000000000057`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.145, 0.}, {0.15, 1.5999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{97.3, 100.}, {156.98456103510858`, 
          165.73835392494314`}}],
        StatusArea[#, 1.5999999999999988`]& ,
        TagBoxNote->"1.5999999999999988"],
       StyleBox["1.5999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.5999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.15, 0.}, {0.155, 0.3999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{100., 102.7}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.3999999999999997]& ,
        TagBoxNote->"0.3999999999999997"],
       StyleBox["0.3999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.3999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.16, 0.}, {0.165, 0.7999999999999994}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{105.4, 108.10000000000001`}, {161.36145748002585`, 
          165.73835392494314`}}],
        StatusArea[#, 0.7999999999999994]& ,
        TagBoxNote->"0.7999999999999994"],
       StyleBox["0.7999999999999994`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.7999999999999994, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.165, 0.}, {0.17, 0.5999999999999995}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{108.10000000000001`, 110.80000000000001`}, {
          162.45568159125517`, 165.73835392494314`}}],
        StatusArea[#, 0.5999999999999995]& ,
        TagBoxNote->"0.5999999999999995"],
       StyleBox["0.5999999999999995`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.5999999999999995, {
         GrayLevel[0]}], "Tooltip"]& ], {}, {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.18, 0.}, {0.185, 0.3999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{116.2, 118.9}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.3999999999999997]& ,
        TagBoxNote->"0.3999999999999997"],
       StyleBox["0.3999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.3999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.19, 0.}, {0.195, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{121.6, 124.3}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], {}, {}, {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.21, 0.}, {0.215, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{132.4, 135.1}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], 
       "Tooltip"]& ], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}}, {}, {}}, {{}, 
    {GrayLevel[0.85], Opacity[0.5], EdgeForm[None], {}, {}, {}, {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.02, 0.}, {0.025, 0.19999999999999998`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{29.800000000000004`, 32.5}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999998`]& ,
        TagBoxNote->"0.19999999999999998"],
       StyleBox["0.19999999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999998`, {
         GrayLevel[0]}], "Tooltip"]& ], {}, {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.035, 0.}, {0.04, 0.20000000000000012`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{37.900000000000006`, 40.60000000000001}, {
          164.64412981371382`, 165.73835392494314`}}],
        StatusArea[#, 0.20000000000000012`]& ,
        TagBoxNote->"0.20000000000000012"],
       StyleBox["0.20000000000000012`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.20000000000000012`, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.045, 0.}, {0.05, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{43.300000000000004`, 46.}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.05, 0.}, {0.055, 0.40000000000000024`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{46., 48.7}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.40000000000000024`]& ,
        TagBoxNote->"0.40000000000000024"],
       StyleBox["0.40000000000000024`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.40000000000000024`, {
         GrayLevel[0]}], "Tooltip"]& ], {}, {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.065, 0.}, {0.07, 0.5999999999999995}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{54.10000000000001, 56.80000000000001}, {
          162.45568159125517`, 165.73835392494314`}}],
        StatusArea[#, 0.5999999999999995]& ,
        TagBoxNote->"0.5999999999999995"],
       StyleBox["0.5999999999999995`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.5999999999999995, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.07, 0.}, {0.075, 0.40000000000000074`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{56.80000000000001, 59.5}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.40000000000000074`]& ,
        TagBoxNote->"0.40000000000000074"],
       StyleBox["0.40000000000000074`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.40000000000000074`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.075, 0.}, {0.08, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{59.5, 62.2}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.08, 0.}, {0.085, 0.7999999999999994}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{62.2, 64.9}, {161.36145748002585`, 
          165.73835392494314`}}],
        StatusArea[#, 0.7999999999999994]& ,
        TagBoxNote->"0.7999999999999994"],
       StyleBox["0.7999999999999994`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.7999999999999994, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.085, 0.}, {0.09, 1.4000000000000026`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{64.9, 67.60000000000001}, {158.07878514633788`, 
          165.73835392494314`}}],
        StatusArea[#, 1.4000000000000026`]& ,
        TagBoxNote->"1.4000000000000026"],
       StyleBox["1.4000000000000026`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.4000000000000026`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.09, 0.}, {0.095, 0.7999999999999994}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{67.60000000000001, 70.3}, {161.36145748002585`, 
          165.73835392494314`}}],
        StatusArea[#, 0.7999999999999994]& ,
        TagBoxNote->"0.7999999999999994"],
       StyleBox["0.7999999999999994`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.7999999999999994, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.095, 0.}, {0.1, 0.9999999999999992}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{70.3, 73.}, {160.26723336879652`, 
          165.73835392494314`}}],
        StatusArea[#, 0.9999999999999992]& ,
        TagBoxNote->"0.9999999999999992"],
       StyleBox["0.9999999999999992`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.9999999999999992, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.1, 0.}, {0.105, 1.2000000000000022`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{73., 75.7}, {159.1730092575672, 
          165.73835392494314`}}],
        StatusArea[#, 1.2000000000000022`]& ,
        TagBoxNote->"1.2000000000000022"],
       StyleBox["1.2000000000000022`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.2000000000000022`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.105, 0.}, {0.11, 2.399999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{75.7, 78.4}, {152.6076645901913, 
          165.73835392494314`}}],
        StatusArea[#, 2.399999999999998]& ,
        TagBoxNote->"2.399999999999998"],
       StyleBox["2.399999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.399999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.11, 0.}, {0.115, 2.199999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{78.4, 81.10000000000001}, {153.70188870142061`, 
          165.73835392494314`}}],
        StatusArea[#, 2.199999999999998]& ,
        TagBoxNote->"2.199999999999998"],
       StyleBox["2.199999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.199999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.115, 0.}, {0.12, 1.8000000000000032`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{81.10000000000001, 83.8}, {155.89033692387923`, 
          165.73835392494314`}}],
        StatusArea[#, 1.8000000000000032`]& ,
        TagBoxNote->"1.8000000000000032"],
       StyleBox["1.8000000000000032`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.8000000000000032`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.12, 0.}, {0.125, 3.1999999999999975`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{83.8, 86.5}, {148.230768145274, 
          165.73835392494314`}}],
        StatusArea[#, 3.1999999999999975`]& ,
        TagBoxNote->"3.1999999999999975"],
       StyleBox["3.1999999999999975`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.1999999999999975`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.125, 0.}, {0.13, 1.7999999999999983`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{86.5, 89.2}, {155.89033692387926`, 
          165.73835392494314`}}],
        StatusArea[#, 1.7999999999999983`]& ,
        TagBoxNote->"1.7999999999999983"],
       StyleBox["1.7999999999999983`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.7999999999999983`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.13, 0.}, {0.135, 2.199999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{89.2, 91.9}, {153.70188870142061`, 
          165.73835392494314`}}],
        StatusArea[#, 2.199999999999998]& ,
        TagBoxNote->"2.199999999999998"],
       StyleBox["2.199999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.199999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.135, 0.}, {0.14, 2.199999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{91.9, 94.60000000000001}, {153.70188870142061`, 
          165.73835392494314`}}],
        StatusArea[#, 2.199999999999998]& ,
        TagBoxNote->"2.199999999999998"],
       StyleBox["2.199999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.199999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.14, 0.}, {0.145, 3.6000000000000165`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{94.60000000000001, 97.3}, {146.04231992281527`, 
          165.73835392494314`}}],
        StatusArea[#, 3.6000000000000165`]& ,
        TagBoxNote->"3.6000000000000165"],
       StyleBox["3.6000000000000165`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.6000000000000165`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.145, 0.}, {0.15, 1.7999999999999983`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{97.3, 100.}, {155.89033692387926`, 
          165.73835392494314`}}],
        StatusArea[#, 1.7999999999999983`]& ,
        TagBoxNote->"1.7999999999999983"],
       StyleBox["1.7999999999999983`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.7999999999999983`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.15, 0.}, {0.155, 2.599999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{100., 102.7}, {151.51344047896197`, 
          165.73835392494314`}}],
        StatusArea[#, 2.599999999999998]& ,
        TagBoxNote->"2.599999999999998"],
       StyleBox["2.599999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.599999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.155, 0.}, {0.16, 2.399999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{102.7, 105.4}, {152.6076645901913, 
          165.73835392494314`}}],
        StatusArea[#, 2.399999999999998]& ,
        TagBoxNote->"2.399999999999998"],
       StyleBox["2.399999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.399999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.16, 0.}, {0.165, 4.199999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{105.4, 108.10000000000001`}, {142.7596475891274, 
          165.73835392494314`}}],
        StatusArea[#, 4.199999999999997]& ,
        TagBoxNote->"4.199999999999997"],
       StyleBox["4.199999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.199999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.165, 0.}, {0.17, 4.799999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{108.10000000000001`, 110.80000000000001`}, {
          139.47697525543944`, 165.73835392494314`}}],
        StatusArea[#, 4.799999999999996]& ,
        TagBoxNote->"4.799999999999996"],
       StyleBox["4.799999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.799999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.17, 0.}, {0.17500000000000002`, 2.199999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{110.80000000000001`, 113.50000000000001`}, {
          153.70188870142061`, 165.73835392494314`}}],
        StatusArea[#, 2.199999999999998]& ,
        TagBoxNote->"2.199999999999998"],
       StyleBox["2.199999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.199999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.17500000000000002`, 0.}, {0.18, 4.000000000000019}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{113.50000000000001`, 116.2}, {143.8538717003566, 
          165.73835392494314`}}],
        StatusArea[#, 4.000000000000019]& ,
        TagBoxNote->"4.000000000000019"],
       StyleBox["4.000000000000019`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.000000000000019, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.18, 0.}, {0.185, 4.199999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{116.2, 118.9}, {142.7596475891274, 
          165.73835392494314`}}],
        StatusArea[#, 4.199999999999997]& ,
        TagBoxNote->"4.199999999999997"],
       StyleBox["4.199999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.199999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.185, 0.}, {0.19, 3.5999999999999965`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{118.9, 121.6}, {146.04231992281535`, 
          165.73835392494314`}}],
        StatusArea[#, 3.5999999999999965`]& ,
        TagBoxNote->"3.5999999999999965"],
       StyleBox["3.5999999999999965`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.5999999999999965`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.19, 0.}, {0.195, 4.799999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{121.6, 124.3}, {139.47697525543944`, 
          165.73835392494314`}}],
        StatusArea[#, 4.799999999999996]& ,
        TagBoxNote->"4.799999999999996"],
       StyleBox["4.799999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.799999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.195, 0.}, {0.2, 3.999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{124.3, 127.}, {143.8538717003567, 
          165.73835392494314`}}],
        StatusArea[#, 3.999999999999997]& ,
        TagBoxNote->"3.999999999999997"],
       StyleBox["3.999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.2, 0.}, {0.20500000000000002`, 4.9999999999999964`},
            "RoundingRadius" -> 0]},
         ImageSizeCache->{{127., 129.70000000000002`}, {138.38275114421012`, 
          165.73835392494314`}}],
        StatusArea[#, 4.9999999999999964`]& ,
        TagBoxNote->"4.9999999999999964"],
       StyleBox["4.9999999999999964`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.9999999999999964`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.20500000000000002`, 0.}, {0.21, 2.600000000000012}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{129.70000000000002`, 132.4}, {151.51344047896188`, 
          165.73835392494314`}}],
        StatusArea[#, 2.600000000000012]& ,
        TagBoxNote->"2.600000000000012"],
       StyleBox["2.600000000000012`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.600000000000012, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.21, 0.}, {0.215, 5.199999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{132.4, 135.1}, {137.2885270329808, 
          165.73835392494314`}}],
        StatusArea[#, 5.199999999999996]& ,
        TagBoxNote->"5.199999999999996"],
       StyleBox["5.199999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[5.199999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.215, 0.}, {0.22, 5.199999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{135.1, 137.8}, {137.2885270329808, 
          165.73835392494314`}}],
        StatusArea[#, 5.199999999999996]& ,
        TagBoxNote->"5.199999999999996"],
       StyleBox["5.199999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[5.199999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.22, 0.}, {0.225, 3.999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{137.8, 140.5}, {143.8538717003567, 
          165.73835392494314`}}],
        StatusArea[#, 3.999999999999997]& ,
        TagBoxNote->"3.999999999999997"],
       StyleBox["3.999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.225, 0.}, {0.23, 4.199999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{140.5, 143.20000000000002`}, {142.7596475891274, 
          165.73835392494314`}}],
        StatusArea[#, 4.199999999999997]& ,
        TagBoxNote->"4.199999999999997"],
       StyleBox["4.199999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.199999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.23, 0.}, {0.23500000000000001`, 5.399999999999995}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{143.20000000000002`, 145.9}, {136.19430292175147`, 
          165.73835392494314`}}],
        StatusArea[#, 5.399999999999995]& ,
        TagBoxNote->"5.399999999999995"],
       StyleBox["5.399999999999995`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[5.399999999999995, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.23500000000000001`, 0.}, {0.24, 5.200000000000024}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{145.9, 148.6}, {137.28852703298065`, 
          165.73835392494314`}}],
        StatusArea[#, 5.200000000000024]& ,
        TagBoxNote->"5.200000000000024"],
       StyleBox["5.200000000000024`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[5.200000000000024, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.24, 0.}, {0.245, 4.199999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{148.6, 151.3}, {142.7596475891274, 
          165.73835392494314`}}],
        StatusArea[#, 4.199999999999997]& ,
        TagBoxNote->"4.199999999999997"],
       StyleBox["4.199999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.199999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.245, 0.}, {0.25, 6.7999999999999945`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{151.3, 154.}, {128.53473414314624`, 
          165.73835392494314`}}],
        StatusArea[#, 6.7999999999999945`]& ,
        TagBoxNote->"6.7999999999999945"],
       StyleBox["6.7999999999999945`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[6.7999999999999945`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.25, 0.}, {0.255, 3.7999999999999967`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{154., 156.7}, {144.94809581158603`, 
          165.73835392494314`}}],
        StatusArea[#, 3.7999999999999967`]& ,
        TagBoxNote->"3.7999999999999967"],
       StyleBox["3.7999999999999967`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.7999999999999967`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.255, 0.}, {0.26, 3.7999999999999967`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{156.7, 159.4}, {144.94809581158603`, 
          165.73835392494314`}}],
        StatusArea[#, 3.7999999999999967`]& ,
        TagBoxNote->"3.7999999999999967"],
       StyleBox["3.7999999999999967`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.7999999999999967`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.26, 0.}, {0.265, 5.199999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{159.4, 162.1}, {137.2885270329808, 
          165.73835392494314`}}],
        StatusArea[#, 5.199999999999996]& ,
        TagBoxNote->"5.199999999999996"],
       StyleBox["5.199999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[5.199999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.265, 0.}, {0.27, 4.599999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{162.1, 164.8}, {140.57119936666876`, 
          165.73835392494314`}}],
        StatusArea[#, 4.599999999999996]& ,
        TagBoxNote->"4.599999999999996"],
       StyleBox["4.599999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.599999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.27, 0.}, {0.275, 2.9999999999999973`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{164.8, 167.5}, {149.32499225650332`, 
          165.73835392494314`}}],
        StatusArea[#, 2.9999999999999973`]& ,
        TagBoxNote->"2.9999999999999973"],
       StyleBox["2.9999999999999973`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.9999999999999973`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.275, 0.}, {0.28, 3.999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{167.5, 170.20000000000002`}, {143.8538717003567, 
          165.73835392494314`}}],
        StatusArea[#, 3.999999999999997]& ,
        TagBoxNote->"3.999999999999997"],
       StyleBox["3.999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.28, 0.}, {0.28500000000000003`, 4.199999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{170.20000000000002`, 172.9}, {142.7596475891274, 
          165.73835392494314`}}],
        StatusArea[#, 4.199999999999997]& ,
        TagBoxNote->"4.199999999999997"],
       StyleBox["4.199999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.199999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.28500000000000003`, 0.}, {0.29, 3.800000000000039}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{172.9, 175.6}, {144.9480958115858, 
          165.73835392494314`}}],
        StatusArea[#, 3.800000000000039]& ,
        TagBoxNote->"3.800000000000039"],
       StyleBox["3.800000000000039`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.800000000000039, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.29, 0.}, {0.295, 4.199999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{175.6, 178.29999999999998`}, {142.7596475891274, 
          165.73835392494314`}}],
        StatusArea[#, 4.199999999999997]& ,
        TagBoxNote->"4.199999999999997"],
       StyleBox["4.199999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.199999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.295, 0.}, {0.3, 3.7999999999999967`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{178.29999999999998`, 181.}, {144.94809581158603`, 
          165.73835392494314`}}],
        StatusArea[#, 3.7999999999999967`]& ,
        TagBoxNote->"3.7999999999999967"],
       StyleBox["3.7999999999999967`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.7999999999999967`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.3, 0.}, {0.305, 2.7999999999999976`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{181., 183.7}, {150.41921636773264`, 
          165.73835392494314`}}],
        StatusArea[#, 2.7999999999999976`]& ,
        TagBoxNote->"2.7999999999999976"],
       StyleBox["2.7999999999999976`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.7999999999999976`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.305, 0.}, {0.31, 3.7999999999999967`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{183.7, 186.4}, {144.94809581158603`, 
          165.73835392494314`}}],
        StatusArea[#, 3.7999999999999967`]& ,
        TagBoxNote->"3.7999999999999967"],
       StyleBox["3.7999999999999967`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.7999999999999967`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.31, 0.}, {0.315, 2.7999999999999976`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{186.4, 189.1}, {150.41921636773264`, 
          165.73835392494314`}}],
        StatusArea[#, 2.7999999999999976`]& ,
        TagBoxNote->"2.7999999999999976"],
       StyleBox["2.7999999999999976`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.7999999999999976`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.315, 0.}, {0.32, 3.5999999999999965`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{189.1, 191.8}, {146.04231992281535`, 
          165.73835392494314`}}],
        StatusArea[#, 3.5999999999999965`]& ,
        TagBoxNote->"3.5999999999999965"],
       StyleBox["3.5999999999999965`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.5999999999999965`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.32, 0.}, {0.325, 2.7999999999999976`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{191.8, 194.5}, {150.41921636773264`, 
          165.73835392494314`}}],
        StatusArea[#, 2.7999999999999976`]& ,
        TagBoxNote->"2.7999999999999976"],
       StyleBox["2.7999999999999976`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.7999999999999976`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.325, 0.}, {0.33, 2.9999999999999973`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{194.5, 197.20000000000002`}, {149.32499225650332`, 
          165.73835392494314`}}],
        StatusArea[#, 2.9999999999999973`]& ,
        TagBoxNote->"2.9999999999999973"],
       StyleBox["2.9999999999999973`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.9999999999999973`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.33, 0.}, {0.335, 2.9999999999999973`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{197.20000000000002`, 199.9}, {149.32499225650332`, 
          165.73835392494314`}}],
        StatusArea[#, 2.9999999999999973`]& ,
        TagBoxNote->"2.9999999999999973"],
       StyleBox["2.9999999999999973`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.9999999999999973`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.335, 0.}, {0.34, 2.399999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{199.9, 202.60000000000002`}, {152.6076645901913, 
          165.73835392494314`}}],
        StatusArea[#, 2.399999999999998]& ,
        TagBoxNote->"2.399999999999998"],
       StyleBox["2.399999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.399999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.34, 0.}, {0.34500000000000003`, 0.9999999999999992},
            "RoundingRadius" -> 0]},
         ImageSizeCache->{{202.60000000000002`, 205.3}, {160.26723336879652`, 
          165.73835392494314`}}],
        StatusArea[#, 0.9999999999999992]& ,
        TagBoxNote->"0.9999999999999992"],
       StyleBox["0.9999999999999992`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.9999999999999992, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.34500000000000003`, 0.}, {0.35000000000000003`, 
           1.7999999999999983`}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{205.3, 208.00000000000003`}, {155.89033692387926`, 
          165.73835392494314`}}],
        StatusArea[#, 1.7999999999999983`]& ,
        TagBoxNote->"1.7999999999999983"],
       StyleBox["1.7999999999999983`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.7999999999999983`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.35000000000000003`, 0.}, {0.355, 
           0.8000000000000081}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{208.00000000000003`, 210.7}, {161.36145748002582`, 
          165.73835392494314`}}],
        StatusArea[#, 0.8000000000000081]& ,
        TagBoxNote->"0.8000000000000081"],
       StyleBox["0.8000000000000081`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.8000000000000081, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.355, 0.}, {0.36, 1.5999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{210.7, 213.4}, {156.98456103510858`, 
          165.73835392494314`}}],
        StatusArea[#, 1.5999999999999988`]& ,
        TagBoxNote->"1.5999999999999988"],
       StyleBox["1.5999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.5999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.36, 0.}, {0.365, 2.199999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{213.4, 216.1}, {153.70188870142061`, 
          165.73835392494314`}}],
        StatusArea[#, 2.199999999999998]& ,
        TagBoxNote->"2.199999999999998"],
       StyleBox["2.199999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.199999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.365, 0.}, {0.37, 1.7999999999999983`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{216.1, 218.8}, {155.89033692387926`, 
          165.73835392494314`}}],
        StatusArea[#, 1.7999999999999983`]& ,
        TagBoxNote->"1.7999999999999983"],
       StyleBox["1.7999999999999983`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.7999999999999983`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.37, 0.}, {0.375, 0.7999999999999994}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{218.8, 221.5}, {161.36145748002585`, 
          165.73835392494314`}}],
        StatusArea[#, 0.7999999999999994]& ,
        TagBoxNote->"0.7999999999999994"],
       StyleBox["0.7999999999999994`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.7999999999999994, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.375, 0.}, {0.38, 1.7999999999999983`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{221.5, 224.2}, {155.89033692387926`, 
          165.73835392494314`}}],
        StatusArea[#, 1.7999999999999983`]& ,
        TagBoxNote->"1.7999999999999983"],
       StyleBox["1.7999999999999983`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.7999999999999983`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.38, 0.}, {0.385, 0.9999999999999992}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{224.2, 226.9}, {160.26723336879652`, 
          165.73835392494314`}}],
        StatusArea[#, 0.9999999999999992]& ,
        TagBoxNote->"0.9999999999999992"],
       StyleBox["0.9999999999999992`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.9999999999999992, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.385, 0.}, {0.39, 1.9999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{226.9, 229.6}, {154.79611281264994`, 
          165.73835392494314`}}],
        StatusArea[#, 1.9999999999999984`]& ,
        TagBoxNote->"1.9999999999999984"],
       StyleBox["1.9999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.9999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.39, 0.}, {0.395, 0.7999999999999994}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{229.6, 232.3}, {161.36145748002585`, 
          165.73835392494314`}}],
        StatusArea[#, 0.7999999999999994]& ,
        TagBoxNote->"0.7999999999999994"],
       StyleBox["0.7999999999999994`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.7999999999999994, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.395, 0.}, {0.4, 1.5999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{232.3, 235.}, {156.98456103510858`, 
          165.73835392494314`}}],
        StatusArea[#, 1.5999999999999988`]& ,
        TagBoxNote->"1.5999999999999988"],
       StyleBox["1.5999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.5999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.4, 0.}, {0.405, 0.3999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{235., 237.70000000000002`}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.3999999999999997]& ,
        TagBoxNote->"0.3999999999999997"],
       StyleBox["0.3999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.3999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.405, 0.}, {0.41000000000000003`, 
           0.5999999999999995}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{237.70000000000002`, 240.4}, {162.45568159125517`, 
          165.73835392494314`}}],
        StatusArea[#, 0.5999999999999995]& ,
        TagBoxNote->"0.5999999999999995"],
       StyleBox["0.5999999999999995`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.5999999999999995, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.41000000000000003`, 0.}, {0.41500000000000004`, 
           0.9999999999999992}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{240.4, 243.10000000000002`}, {160.26723336879652`, 
          165.73835392494314`}}],
        StatusArea[#, 0.9999999999999992]& ,
        TagBoxNote->"0.9999999999999992"],
       StyleBox["0.9999999999999992`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.9999999999999992, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.41500000000000004`, 0.}, {0.42, 0.4000000000000041},
            "RoundingRadius" -> 0]},
         ImageSizeCache->{{243.10000000000002`, 245.79999999999998`}, {
          163.54990570248447`, 165.73835392494314`}}],
        StatusArea[#, 0.4000000000000041]& ,
        TagBoxNote->"0.4000000000000041"],
       StyleBox["0.4000000000000041`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.4000000000000041, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.42, 0.}, {0.425, 1.3999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{245.79999999999998`, 248.5}, {158.0787851463379, 
          165.73835392494314`}}],
        StatusArea[#, 1.3999999999999988`]& ,
        TagBoxNote->"1.3999999999999988"],
       StyleBox["1.3999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.3999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.425, 0.}, {0.43, 0.3999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{248.5, 251.2}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.3999999999999997]& ,
        TagBoxNote->"0.3999999999999997"],
       StyleBox["0.3999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.3999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.435, 0.}, {0.44, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{253.9, 256.6}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.445, 0.}, {0.45, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{259.3, 262.}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.45, 0.}, {0.455, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{262., 264.70000000000005`}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], {}, {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.465, 0.}, {0.47000000000000003`, 
           0.19999999999999984`}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{270.1, 272.8}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], 
       "Tooltip"]& ], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {}, {}}, {{}, 
    {RGBColor[0.5666666666666667, 0.5666666666666667, 0.5666666666666667], 
     Opacity[0.5], EdgeForm[
     None], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.455, 0.}, {0.46, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{264.70000000000005`, 267.40000000000003`}, {
          164.64412981371382`, 165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.465, 0.}, {0.47000000000000003`, 
           0.3999999999999997}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{270.1, 272.8}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.3999999999999997]& ,
        TagBoxNote->"0.3999999999999997"],
       StyleBox["0.3999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.3999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.47500000000000003`, 0.}, {0.48, 0.4000000000000041},
            "RoundingRadius" -> 0]},
         ImageSizeCache->{{275.5, 278.2}, {163.54990570248447`, 
          165.73835392494314`}}],
        StatusArea[#, 0.4000000000000041]& ,
        TagBoxNote->"0.4000000000000041"],
       StyleBox["0.4000000000000041`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.4000000000000041, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.485, 0.}, {0.49, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{280.9, 283.6}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.49, 0.}, {0.495, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{283.6, 286.3}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.495, 0.}, {0.5, 0.7999999999999994}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{286.3, 289.}, {161.36145748002585`, 
          165.73835392494314`}}],
        StatusArea[#, 0.7999999999999994]& ,
        TagBoxNote->"0.7999999999999994"],
       StyleBox["0.7999999999999994`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.7999999999999994, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.5, 0.}, {0.505, 0.5999999999999995}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{289., 291.7}, {162.45568159125517`, 
          165.73835392494314`}}],
        StatusArea[#, 0.5999999999999995]& ,
        TagBoxNote->"0.5999999999999995"],
       StyleBox["0.5999999999999995`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.5999999999999995, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.505, 0.}, {0.51, 0.5999999999999995}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{291.7, 294.4}, {162.45568159125517`, 
          165.73835392494314`}}],
        StatusArea[#, 0.5999999999999995]& ,
        TagBoxNote->"0.5999999999999995"],
       StyleBox["0.5999999999999995`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.5999999999999995, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.51, 0.}, {0.515, 0.3999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{294.4, 297.1}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.3999999999999997]& ,
        TagBoxNote->"0.3999999999999997"],
       StyleBox["0.3999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.3999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.515, 0.}, {0.52, 0.3999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{297.1, 299.8}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.3999999999999997]& ,
        TagBoxNote->"0.3999999999999997"],
       StyleBox["0.3999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.3999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.52, 0.}, {0.525, 1.5999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{299.8, 302.5}, {156.98456103510858`, 
          165.73835392494314`}}],
        StatusArea[#, 1.5999999999999988`]& ,
        TagBoxNote->"1.5999999999999988"],
       StyleBox["1.5999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.5999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.525, 0.}, {0.53, 0.5999999999999995}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{302.5, 305.2}, {162.45568159125517`, 
          165.73835392494314`}}],
        StatusArea[#, 0.5999999999999995]& ,
        TagBoxNote->"0.5999999999999995"],
       StyleBox["0.5999999999999995`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.5999999999999995, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.53, 0.}, {0.535, 1.3999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{305.2, 307.90000000000003`}, {158.0787851463379, 
          165.73835392494314`}}],
        StatusArea[#, 1.3999999999999988`]& ,
        TagBoxNote->"1.3999999999999988"],
       StyleBox["1.3999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.3999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.535, 0.}, {0.54, 2.199999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{307.90000000000003`, 310.6}, {153.70188870142061`, 
          165.73835392494314`}}],
        StatusArea[#, 2.199999999999998]& ,
        TagBoxNote->"2.199999999999998"],
       StyleBox["2.199999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.199999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.54, 0.}, {0.545, 1.3999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{310.6, 313.3}, {158.0787851463379, 
          165.73835392494314`}}],
        StatusArea[#, 1.3999999999999988`]& ,
        TagBoxNote->"1.3999999999999988"],
       StyleBox["1.3999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.3999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.545, 0.}, {0.55, 1.5999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{313.3, 316.}, {156.98456103510858`, 
          165.73835392494314`}}],
        StatusArea[#, 1.5999999999999988`]& ,
        TagBoxNote->"1.5999999999999988"],
       StyleBox["1.5999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.5999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.55, 0.}, {0.555, 0.7999999999999994}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{316., 318.70000000000005`}, {161.36145748002585`, 
          165.73835392494314`}}],
        StatusArea[#, 0.7999999999999994]& ,
        TagBoxNote->"0.7999999999999994"],
       StyleBox["0.7999999999999994`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.7999999999999994, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.555, 0.}, {0.56, 1.3999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{318.70000000000005`, 321.40000000000003`}, {
          158.0787851463379, 165.73835392494314`}}],
        StatusArea[#, 1.3999999999999988`]& ,
        TagBoxNote->"1.3999999999999988"],
       StyleBox["1.3999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.3999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.56, 0.}, {0.5650000000000001, 1.5999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{321.40000000000003`, 324.1}, {156.98456103510858`, 
          165.73835392494314`}}],
        StatusArea[#, 1.5999999999999988`]& ,
        TagBoxNote->"1.5999999999999988"],
       StyleBox["1.5999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.5999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.5650000000000001, 0.}, {0.5700000000000001, 
           1.7999999999999983`}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{324.1, 326.8}, {155.89033692387926`, 
          165.73835392494314`}}],
        StatusArea[#, 1.7999999999999983`]& ,
        TagBoxNote->"1.7999999999999983"],
       StyleBox["1.7999999999999983`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.7999999999999983`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.5700000000000001, 0.}, {0.5750000000000001, 
           1.9999999999999984`}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{326.8, 329.50000000000006`}, {154.79611281264994`, 
          165.73835392494314`}}],
        StatusArea[#, 1.9999999999999984`]& ,
        TagBoxNote->"1.9999999999999984"],
       StyleBox["1.9999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.9999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.5750000000000001, 0.}, {0.58, 2.4000000000000514`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{329.50000000000006`, 332.2}, {152.607664590191, 
          165.73835392494314`}}],
        StatusArea[#, 2.4000000000000514`]& ,
        TagBoxNote->"2.4000000000000514"],
       StyleBox["2.4000000000000514`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.4000000000000514`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.58, 0.}, {0.585, 1.9999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{332.2, 334.9}, {154.79611281264994`, 
          165.73835392494314`}}],
        StatusArea[#, 1.9999999999999984`]& ,
        TagBoxNote->"1.9999999999999984"],
       StyleBox["1.9999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.9999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.585, 0.}, {0.59, 2.399999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{334.9, 337.59999999999997`}, {152.6076645901913, 
          165.73835392494314`}}],
        StatusArea[#, 2.399999999999998]& ,
        TagBoxNote->"2.399999999999998"],
       StyleBox["2.399999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.399999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.59, 0.}, {0.595, 1.9999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{337.59999999999997`, 340.3}, {154.79611281264994`, 
          165.73835392494314`}}],
        StatusArea[#, 1.9999999999999984`]& ,
        TagBoxNote->"1.9999999999999984"],
       StyleBox["1.9999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.9999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.595, 0.}, {0.6, 3.3999999999999972`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{340.3, 343.}, {147.13654403404468`, 
          165.73835392494314`}}],
        StatusArea[#, 3.3999999999999972`]& ,
        TagBoxNote->"3.3999999999999972"],
       StyleBox["3.3999999999999972`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.3999999999999972`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.6, 0.}, {0.605, 2.399999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{343., 345.7}, {152.6076645901913, 
          165.73835392494314`}}],
        StatusArea[#, 2.399999999999998]& ,
        TagBoxNote->"2.399999999999998"],
       StyleBox["2.399999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.399999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.605, 0.}, {0.61, 2.599999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{345.7, 348.4}, {151.51344047896197`, 
          165.73835392494314`}}],
        StatusArea[#, 2.599999999999998]& ,
        TagBoxNote->"2.599999999999998"],
       StyleBox["2.599999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.599999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.61, 0.}, {0.615, 3.3999999999999972`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{348.4, 351.1}, {147.13654403404468`, 
          165.73835392494314`}}],
        StatusArea[#, 3.3999999999999972`]& ,
        TagBoxNote->"3.3999999999999972"],
       StyleBox["3.3999999999999972`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.3999999999999972`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.615, 0.}, {0.62, 1.9999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{351.1, 353.8}, {154.79611281264994`, 
          165.73835392494314`}}],
        StatusArea[#, 1.9999999999999984`]& ,
        TagBoxNote->"1.9999999999999984"],
       StyleBox["1.9999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.9999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.62, 0.}, {0.625, 3.7999999999999967`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{353.8, 356.5}, {144.94809581158603`, 
          165.73835392494314`}}],
        StatusArea[#, 3.7999999999999967`]& ,
        TagBoxNote->"3.7999999999999967"],
       StyleBox["3.7999999999999967`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.7999999999999967`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.625, 0.}, {0.63, 2.599999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{356.5, 359.2}, {151.51344047896197`, 
          165.73835392494314`}}],
        StatusArea[#, 2.599999999999998]& ,
        TagBoxNote->"2.599999999999998"],
       StyleBox["2.599999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.599999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.63, 0.}, {0.635, 4.599999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{359.2, 361.9}, {140.57119936666876`, 
          165.73835392494314`}}],
        StatusArea[#, 4.599999999999996]& ,
        TagBoxNote->"4.599999999999996"],
       StyleBox["4.599999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.599999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.635, 0.}, {0.64, 1.9999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{361.9, 364.6}, {154.79611281264994`, 
          165.73835392494314`}}],
        StatusArea[#, 1.9999999999999984`]& ,
        TagBoxNote->"1.9999999999999984"],
       StyleBox["1.9999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.9999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.64, 0.}, {0.645, 2.9999999999999973`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{364.6, 367.3}, {149.32499225650332`, 
          165.73835392494314`}}],
        StatusArea[#, 2.9999999999999973`]& ,
        TagBoxNote->"2.9999999999999973"],
       StyleBox["2.9999999999999973`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.9999999999999973`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.645, 0.}, {0.65, 2.7999999999999976`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{367.3, 370.}, {150.41921636773264`, 
          165.73835392494314`}}],
        StatusArea[#, 2.7999999999999976`]& ,
        TagBoxNote->"2.7999999999999976"],
       StyleBox["2.7999999999999976`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.7999999999999976`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.65, 0.}, {0.655, 3.999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{370., 372.7}, {143.8538717003567, 
          165.73835392494314`}}],
        StatusArea[#, 3.999999999999997]& ,
        TagBoxNote->"3.999999999999997"],
       StyleBox["3.999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.655, 0.}, {0.66, 2.7999999999999976`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{372.7, 375.40000000000003`}, {150.41921636773264`, 
          165.73835392494314`}}],
        StatusArea[#, 2.7999999999999976`]& ,
        TagBoxNote->"2.7999999999999976"],
       StyleBox["2.7999999999999976`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.7999999999999976`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.66, 0.}, {0.665, 3.1999999999999975`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{375.40000000000003`, 378.1}, {148.230768145274, 
          165.73835392494314`}}],
        StatusArea[#, 3.1999999999999975`]& ,
        TagBoxNote->"3.1999999999999975"],
       StyleBox["3.1999999999999975`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.1999999999999975`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.665, 0.}, {0.67, 4.599999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{378.1, 380.8}, {140.57119936666876`, 
          165.73835392494314`}}],
        StatusArea[#, 4.599999999999996]& ,
        TagBoxNote->"4.599999999999996"],
       StyleBox["4.599999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.599999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.67, 0.}, {0.675, 3.5999999999999965`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{380.8, 383.5}, {146.04231992281535`, 
          165.73835392494314`}}],
        StatusArea[#, 3.5999999999999965`]& ,
        TagBoxNote->"3.5999999999999965"],
       StyleBox["3.5999999999999965`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.5999999999999965`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.675, 0.}, {0.68, 3.1999999999999975`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{383.5, 386.20000000000005`}, {148.230768145274, 
          165.73835392494314`}}],
        StatusArea[#, 3.1999999999999975`]& ,
        TagBoxNote->"3.1999999999999975"],
       StyleBox["3.1999999999999975`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.1999999999999975`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.68, 0.}, {0.685, 2.7999999999999976`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{386.20000000000005`, 388.90000000000003`}, {
          150.41921636773264`, 165.73835392494314`}}],
        StatusArea[#, 2.7999999999999976`]& ,
        TagBoxNote->"2.7999999999999976"],
       StyleBox["2.7999999999999976`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.7999999999999976`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.685, 0.}, {0.6900000000000001, 4.199999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{388.90000000000003`, 391.6}, {142.7596475891274, 
          165.73835392494314`}}],
        StatusArea[#, 4.199999999999997]& ,
        TagBoxNote->"4.199999999999997"],
       StyleBox["4.199999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.199999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.6900000000000001, 0.}, {0.6950000000000001, 
           4.9999999999999964`}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{391.6, 394.3}, {138.38275114421012`, 
          165.73835392494314`}}],
        StatusArea[#, 4.9999999999999964`]& ,
        TagBoxNote->"4.9999999999999964"],
       StyleBox["4.9999999999999964`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.9999999999999964`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.6950000000000001, 0.}, {0.7000000000000001, 
           3.3999999999999972`}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{394.3, 397.00000000000006`}, {147.13654403404468`, 
          165.73835392494314`}}],
        StatusArea[#, 3.3999999999999972`]& ,
        TagBoxNote->"3.3999999999999972"],
       StyleBox["3.3999999999999972`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.3999999999999972`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.7000000000000001, 0.}, {0.705, 5.6000000000001195`},
            "RoundingRadius" -> 0]},
         ImageSizeCache->{{397.00000000000006`, 399.7}, {135.10007881052147`, 
          165.73835392494314`}}],
        StatusArea[#, 5.6000000000001195`]& ,
        TagBoxNote->"5.6000000000001195"],
       StyleBox["5.6000000000001195`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[5.6000000000001195`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.705, 0.}, {0.71, 3.1999999999999975`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{399.7, 402.4}, {148.230768145274, 
          165.73835392494314`}}],
        StatusArea[#, 3.1999999999999975`]& ,
        TagBoxNote->"3.1999999999999975"],
       StyleBox["3.1999999999999975`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.1999999999999975`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.71, 0.}, {0.715, 4.199999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{402.4, 405.09999999999997`}, {142.7596475891274, 
          165.73835392494314`}}],
        StatusArea[#, 4.199999999999997]& ,
        TagBoxNote->"4.199999999999997"],
       StyleBox["4.199999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.199999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.715, 0.}, {0.72, 2.599999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{405.09999999999997`, 407.8}, {151.51344047896197`, 
          165.73835392494314`}}],
        StatusArea[#, 2.599999999999998]& ,
        TagBoxNote->"2.599999999999998"],
       StyleBox["2.599999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.599999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.72, 0.}, {0.725, 4.599999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{407.8, 410.5}, {140.57119936666876`, 
          165.73835392494314`}}],
        StatusArea[#, 4.599999999999996]& ,
        TagBoxNote->"4.599999999999996"],
       StyleBox["4.599999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.599999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.725, 0.}, {0.73, 1.7999999999999983`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{410.5, 413.2}, {155.89033692387926`, 
          165.73835392494314`}}],
        StatusArea[#, 1.7999999999999983`]& ,
        TagBoxNote->"1.7999999999999983"],
       StyleBox["1.7999999999999983`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.7999999999999983`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.73, 0.}, {0.735, 3.7999999999999967`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{413.2, 415.9}, {144.94809581158603`, 
          165.73835392494314`}}],
        StatusArea[#, 3.7999999999999967`]& ,
        TagBoxNote->"3.7999999999999967"],
       StyleBox["3.7999999999999967`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.7999999999999967`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.735, 0.}, {0.74, 3.7999999999999967`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{415.9, 418.6}, {144.94809581158603`, 
          165.73835392494314`}}],
        StatusArea[#, 3.7999999999999967`]& ,
        TagBoxNote->"3.7999999999999967"],
       StyleBox["3.7999999999999967`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.7999999999999967`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.74, 0.}, {0.745, 3.1999999999999975`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{418.6, 421.3}, {148.230768145274, 
          165.73835392494314`}}],
        StatusArea[#, 3.1999999999999975`]& ,
        TagBoxNote->"3.1999999999999975"],
       StyleBox["3.1999999999999975`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.1999999999999975`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.745, 0.}, {0.75, 4.799999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{421.3, 424.}, {139.47697525543944`, 
          165.73835392494314`}}],
        StatusArea[#, 4.799999999999996]& ,
        TagBoxNote->"4.799999999999996"],
       StyleBox["4.799999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.799999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.75, 0.}, {0.755, 4.799999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{424., 426.7}, {139.47697525543944`, 
          165.73835392494314`}}],
        StatusArea[#, 4.799999999999996]& ,
        TagBoxNote->"4.799999999999996"],
       StyleBox["4.799999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.799999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.755, 0.}, {0.76, 4.599999999999996}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{426.7, 429.4}, {140.57119936666876`, 
          165.73835392494314`}}],
        StatusArea[#, 4.599999999999996]& ,
        TagBoxNote->"4.599999999999996"],
       StyleBox["4.599999999999996`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[4.599999999999996, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.76, 0.}, {0.765, 2.199999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{429.4, 432.1}, {153.70188870142061`, 
          165.73835392494314`}}],
        StatusArea[#, 2.199999999999998]& ,
        TagBoxNote->"2.199999999999998"],
       StyleBox["2.199999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.199999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.765, 0.}, {0.77, 3.1999999999999975`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{432.1, 434.8}, {148.230768145274, 
          165.73835392494314`}}],
        StatusArea[#, 3.1999999999999975`]& ,
        TagBoxNote->"3.1999999999999975"],
       StyleBox["3.1999999999999975`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.1999999999999975`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.77, 0.}, {0.775, 3.3999999999999972`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{434.8, 437.5}, {147.13654403404468`, 
          165.73835392494314`}}],
        StatusArea[#, 3.3999999999999972`]& ,
        TagBoxNote->"3.3999999999999972"],
       StyleBox["3.3999999999999972`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.3999999999999972`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.775, 0.}, {0.78, 3.999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{437.5, 440.2}, {143.8538717003567, 
          165.73835392494314`}}],
        StatusArea[#, 3.999999999999997]& ,
        TagBoxNote->"3.999999999999997"],
       StyleBox["3.999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.78, 0.}, {0.785, 2.399999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{440.2, 442.90000000000003`}, {152.6076645901913, 
          165.73835392494314`}}],
        StatusArea[#, 2.399999999999998]& ,
        TagBoxNote->"2.399999999999998"],
       StyleBox["2.399999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.399999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.785, 0.}, {0.79, 3.5999999999999965`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{442.90000000000003`, 445.6}, {146.04231992281535`, 
          165.73835392494314`}}],
        StatusArea[#, 3.5999999999999965`]& ,
        TagBoxNote->"3.5999999999999965"],
       StyleBox["3.5999999999999965`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.5999999999999965`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.79, 0.}, {0.795, 1.9999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{445.6, 448.3}, {154.79611281264994`, 
          165.73835392494314`}}],
        StatusArea[#, 1.9999999999999984`]& ,
        TagBoxNote->"1.9999999999999984"],
       StyleBox["1.9999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.9999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.795, 0.}, {0.8, 1.9999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{448.3, 451.}, {154.79611281264994`, 
          165.73835392494314`}}],
        StatusArea[#, 1.9999999999999984`]& ,
        TagBoxNote->"1.9999999999999984"],
       StyleBox["1.9999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.9999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.8, 0.}, {0.805, 1.199999999999999}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{451., 453.70000000000005`}, {159.1730092575672, 
          165.73835392494314`}}],
        StatusArea[#, 1.199999999999999]& ,
        TagBoxNote->"1.199999999999999"],
       StyleBox["1.199999999999999`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.199999999999999, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.805, 0.}, {0.81, 3.1999999999999975`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{453.70000000000005`, 456.40000000000003`}, {
          148.230768145274, 165.73835392494314`}}],
        StatusArea[#, 3.1999999999999975`]& ,
        TagBoxNote->"3.1999999999999975"],
       StyleBox["3.1999999999999975`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.1999999999999975`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.81, 0.}, {0.8150000000000001, 3.5999999999999965`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{456.40000000000003`, 459.1}, {146.04231992281535`, 
          165.73835392494314`}}],
        StatusArea[#, 3.5999999999999965`]& ,
        TagBoxNote->"3.5999999999999965"],
       StyleBox["3.5999999999999965`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[3.5999999999999965`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.8150000000000001, 0.}, {0.8200000000000001, 
           0.9999999999999992}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{459.1, 461.8}, {160.26723336879652`, 
          165.73835392494314`}}],
        StatusArea[#, 0.9999999999999992]& ,
        TagBoxNote->"0.9999999999999992"],
       StyleBox["0.9999999999999992`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.9999999999999992, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.8200000000000001, 0.}, {0.8250000000000001, 
           2.7999999999999976`}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{461.8, 464.50000000000006`}, {150.41921636773264`, 
          165.73835392494314`}}],
        StatusArea[#, 2.7999999999999976`]& ,
        TagBoxNote->"2.7999999999999976"],
       StyleBox["2.7999999999999976`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.7999999999999976`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.8250000000000001, 0.}, {0.8300000000000001, 
           2.199999999999998}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{464.50000000000006`, 467.20000000000005`}, {
          153.70188870142061`, 165.73835392494314`}}],
        StatusArea[#, 2.199999999999998]& ,
        TagBoxNote->"2.199999999999998"],
       StyleBox["2.199999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.199999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.8300000000000001, 0.}, {0.835, 1.4000000000000299`},
            "RoundingRadius" -> 0]},
         ImageSizeCache->{{467.20000000000005`, 469.9}, {158.07878514633774`, 
          165.73835392494314`}}],
        StatusArea[#, 1.4000000000000299`]& ,
        TagBoxNote->"1.4000000000000299"],
       StyleBox["1.4000000000000299`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.4000000000000299`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.835, 0.}, {0.84, 1.199999999999999}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{469.9, 472.59999999999997`}, {159.1730092575672, 
          165.73835392494314`}}],
        StatusArea[#, 1.199999999999999]& ,
        TagBoxNote->"1.199999999999999"],
       StyleBox["1.199999999999999`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.199999999999999, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.84, 0.}, {0.845, 0.9999999999999992}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{472.59999999999997`, 475.3}, {160.26723336879652`, 
          165.73835392494314`}}],
        StatusArea[#, 0.9999999999999992]& ,
        TagBoxNote->"0.9999999999999992"],
       StyleBox["0.9999999999999992`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.9999999999999992, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.845, 0.}, {0.85, 1.3999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{475.3, 478.}, {158.0787851463379, 
          165.73835392494314`}}],
        StatusArea[#, 1.3999999999999988`]& ,
        TagBoxNote->"1.3999999999999988"],
       StyleBox["1.3999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.3999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.85, 0.}, {0.855, 2.199999999999998}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{478., 480.7}, {153.70188870142061`, 
          165.73835392494314`}}],
        StatusArea[#, 2.199999999999998]& ,
        TagBoxNote->"2.199999999999998"],
       StyleBox["2.199999999999998`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[2.199999999999998, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.855, 0.}, {0.86, 0.7999999999999994}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{480.7, 483.4}, {161.36145748002585`, 
          165.73835392494314`}}],
        StatusArea[#, 0.7999999999999994]& ,
        TagBoxNote->"0.7999999999999994"],
       StyleBox["0.7999999999999994`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.7999999999999994, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.86, 0.}, {0.865, 1.5999999999999988`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{483.4, 486.1}, {156.98456103510858`, 
          165.73835392494314`}}],
        StatusArea[#, 1.5999999999999988`]& ,
        TagBoxNote->"1.5999999999999988"],
       StyleBox["1.5999999999999988`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.5999999999999988`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.865, 0.}, {0.87, 1.7999999999999983`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{486.1, 488.8}, {155.89033692387926`, 
          165.73835392494314`}}],
        StatusArea[#, 1.7999999999999983`]& ,
        TagBoxNote->"1.7999999999999983"],
       StyleBox["1.7999999999999983`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[1.7999999999999983`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.87, 0.}, {0.875, 0.3999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{488.8, 491.5}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.3999999999999997]& ,
        TagBoxNote->"0.3999999999999997"],
       StyleBox["0.3999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.3999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.875, 0.}, {0.88, 0.9999999999999992}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{491.5, 494.2}, {160.26723336879652`, 
          165.73835392494314`}}],
        StatusArea[#, 0.9999999999999992]& ,
        TagBoxNote->"0.9999999999999992"],
       StyleBox["0.9999999999999992`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.9999999999999992, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.88, 0.}, {0.885, 0.3999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{494.2, 496.9}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.3999999999999997]& ,
        TagBoxNote->"0.3999999999999997"],
       StyleBox["0.3999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.3999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.885, 0.}, {0.89, 0.7999999999999994}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{496.9, 499.6}, {161.36145748002585`, 
          165.73835392494314`}}],
        StatusArea[#, 0.7999999999999994]& ,
        TagBoxNote->"0.7999999999999994"],
       StyleBox["0.7999999999999994`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.7999999999999994, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.89, 0.}, {0.895, 0.5999999999999995}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{499.6, 502.3}, {162.45568159125517`, 
          165.73835392494314`}}],
        StatusArea[#, 0.5999999999999995]& ,
        TagBoxNote->"0.5999999999999995"],
       StyleBox["0.5999999999999995`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.5999999999999995, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.895, 0.}, {0.9, 0.3999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{502.3, 505.}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.3999999999999997]& ,
        TagBoxNote->"0.3999999999999997"],
       StyleBox["0.3999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.3999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.9, 0.}, {0.905, 0.3999999999999997}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{505., 507.7}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.3999999999999997]& ,
        TagBoxNote->"0.3999999999999997"],
       StyleBox["0.3999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.3999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.905, 0.}, {0.91, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{507.7, 510.40000000000003`}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.91, 0.}, {0.915, 0.7999999999999994}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{510.40000000000003`, 513.1}, {161.36145748002585`, 
          165.73835392494314`}}],
        StatusArea[#, 0.7999999999999994]& ,
        TagBoxNote->"0.7999999999999994"],
       StyleBox["0.7999999999999994`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.7999999999999994, {
         GrayLevel[0]}], "Tooltip"]& ], {}, {}, {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.93, 0.}, {0.935, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{521.2, 523.9000000000001}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.9400000000000001, 0.}, {0.9450000000000001, 
           0.3999999999999997}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{526.6, 529.3000000000001}, {163.5499057024845, 
          165.73835392494314`}}],
        StatusArea[#, 0.3999999999999997]& ,
        TagBoxNote->"0.3999999999999997"],
       StyleBox["0.3999999999999997`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.3999999999999997, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.9500000000000001, 0.}, {0.9550000000000001, 
           0.19999999999999984`}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{532., 534.7}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ], {}, {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.965, 0.}, {0.97, 0.19999999999999984`}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{540.1, 542.8}, {164.64412981371382`, 
          165.73835392494314`}}],
        StatusArea[#, 0.19999999999999984`]& ,
        TagBoxNote->"0.19999999999999984"],
       StyleBox["0.19999999999999984`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.19999999999999984`, {
         GrayLevel[0]}], "Tooltip"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Lambda]\"", TraditionalForm], 
    FormBox["\"P(\[Lambda])\"", TraditionalForm]},
  AxesOrigin->{0., 0},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  ImageSize->Large,
  LabelStyle->15,
  PlotRange->{{0, 1}, {0, 61}},
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.50661142101952*^9, 3.506611427368799*^9}, 
   3.506611471748509*^9, 3.50661232124912*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{
    RowBox[{"ToString", "[", 
     RowBox[{"NotebookDirectory", "[", "]"}], "]"}], "<>", "\"\</plots\>\""}],
    "]"}], ";"}]], "Input",
 CellChangeTimes->{3.506358245795662*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<lambda-prob-bures-trqs.pdf\>\"", ",", "masterplotBures"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Run", "[", 
   "\"\< pdf2ps  -dLanguageLevel=3 lambda-prob-bures-trqs.pdf \
lambda-prob-bures-trqs.eps\>\"", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.506358188785643*^9, 3.506358204681434*^9}, 
   3.506358540566231*^9, {3.506611807601054*^9, 3.506611825941661*^9}}]
}, Open  ]]
},
WindowSize->{1280, 718},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"8.0 for Linux x86 (32-bit) (October 10, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3545409183-1237171"->{
  Cell[3262, 90, 379, 7, 62, "Print",
   CellTags->"Info3545409183-1237171"]},
 "Info3545386866-1127675"->{
  Cell[5438, 156, 467, 7, 100, "Print",
   CellTags->"Info3545386866-1127675"]},
 "Info3545386871-1127675"->{
  Cell[7581, 214, 480, 8, 100, "Print",
   CellTags->"Info3545386871-1127675"]},
 "Info3545386876-1127675"->{
  Cell[9771, 277, 313, 5, 42, "Print",
   CellTags->"Info3545386876-1127675"]},
 "Info3545386885-1127675"->{
  Cell[40103, 1165, 315, 5, 42, "Print",
   CellTags->"Info3545386885-1127675"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3545409183-1237171", 252785, 7195},
 {"Info3545386866-1127675", 252893, 7198},
 {"Info3545386871-1127675", 253003, 7201},
 {"Info3545386876-1127675", 253113, 7204},
 {"Info3545386885-1127675", 253222, 7207}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 101, 1, 74, "Section"],
Cell[CellGroupData[{
Cell[705, 27, 164, 3, 30, "Input"],
Cell[CellGroupData[{
Cell[894, 34, 702, 15, 23, "Print"],
Cell[1599, 51, 611, 9, 23, "Print"],
Cell[2213, 62, 640, 9, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2914, 78, 158, 2, 74, "Section"],
Cell[CellGroupData[{
Cell[3097, 84, 162, 4, 30, "Input"],
Cell[3262, 90, 379, 7, 62, "Print",
 CellTags->"Info3545409183-1237171"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3678, 102, 479, 10, 30, "Input"],
Cell[4160, 114, 152, 2, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4361, 122, 107, 1, 74, "Section"],
Cell[CellGroupData[{
Cell[4493, 127, 309, 7, 30, "Input"],
Cell[4805, 136, 89, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4943, 143, 147, 2, 74, "Section"],
Cell[CellGroupData[{
Cell[5115, 149, 320, 5, 30, "Input"],
Cell[5438, 156, 467, 7, 100, "Print",
 CellTags->"Info3545386866-1127675"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5942, 168, 621, 15, 30, "Input"],
Cell[6566, 185, 622, 12, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7237, 203, 167, 2, 74, "Section"],
Cell[CellGroupData[{
Cell[7429, 209, 149, 3, 30, "Input"],
Cell[7581, 214, 480, 8, 100, "Print",
 CellTags->"Info3545386871-1127675"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8098, 227, 507, 14, 30, "Input"],
Cell[8608, 243, 755, 17, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9412, 266, 176, 2, 74, "Section"],
Cell[CellGroupData[{
Cell[9613, 272, 155, 3, 30, "Input"],
Cell[9771, 277, 313, 5, 42, "Print",
 CellTags->"Info3545386876-1127675"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10121, 287, 706, 12, 29, "Input"],
Cell[10830, 301, 28945, 848, 241, 25979, 797, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39824, 1155, 125, 2, 74, "Section"],
Cell[CellGroupData[{
Cell[39974, 1161, 126, 2, 29, "Input"],
Cell[40103, 1165, 315, 5, 42, "Print",
 CellTags->"Info3545386885-1127675"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40455, 1175, 305, 5, 29, "Input"],
Cell[40763, 1182, 13778, 277, 192, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[54590, 1465, 183, 2, 74, "Section"],
Cell[54776, 1469, 590, 12, 29, "Input"],
Cell[55369, 1483, 621, 16, 29, "Input"],
Cell[55993, 1501, 1791, 43, 66, "Input"],
Cell[57787, 1546, 246, 7, 29, "Input"],
Cell[58036, 1555, 450, 11, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58523, 1571, 235, 3, 74, "Section"],
Cell[58761, 1576, 548, 11, 29, "Input"],
Cell[59312, 1589, 627, 16, 29, "Input"],
Cell[CellGroupData[{
Cell[59964, 1609, 479, 12, 29, "Input"],
Cell[60446, 1623, 19957, 590, 238, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80440, 2218, 1722, 40, 66, "Input"],
Cell[82165, 2260, 169557, 4898, 393, "Output"]
}, Open  ]],
Cell[251737, 7161, 246, 7, 29, "Input"],
Cell[251986, 7170, 463, 11, 48, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
